@@ -437,10 +437,15 @@ SKGError SKGBookmarkPluginDockWidget::createNodeFromPage(SKGTabPage* iPage, cons
 
         QString defaultName = iPage->objectName();
         QString defaultIcon;
-        SKGInterfacePlugin* plugin = SKGMainPanel::getMainPanel()->getPluginByName(defaultName);
-        if (plugin != nullptr) {
-            defaultName = plugin->title();
-            defaultIcon = plugin->icon();
+
+        // Get title and icon from tab (in case of changed in bookmark)
+        auto tab = SKGMainPanel::getMainPanel()->getTabWidget();
+        if (tab) {
+            auto index = tab->indexOf(iPage);
+            if (index != -1) {
+                defaultName = tab-> tabText(index);
+                defaultIcon = tab-> tabIcon(index).name();
+            }
         }
         name += defaultName;
 
