@@ -27,6 +27,7 @@
 #include <kstandardaction.h>
 
 #include "skgdashboard_settings.h"
+#include "skgdashboardboardwidget.h"
 #include "skgdashboardpluginwidget.h"
 #include "skgmainpanel.h"
 #include "skgtraces.h"
@@ -62,6 +63,24 @@ bool SKGDashboardPlugin::setupActions(SKGDocument* iDocument)
     return true;
 }
 
+int SKGDashboardPlugin::getNbDashboardWidgets()
+{
+    return 1;
+}
+
+QString SKGDashboardPlugin::getDashboardWidgetTitle(int iIndex)
+{
+    Q_UNUSED(iIndex)
+    return i18nc("Noun, the title of a section", "Sub dashboard");
+}
+
+SKGBoardWidget* SKGDashboardPlugin::getDashboardWidget(int iIndex)
+{
+    Q_UNUSED(iIndex)
+    return new SKGDashboardboardWidget(SKGMainPanel::getMainPanel(), m_currentDocument);
+}
+
+
 SKGTabPage* SKGDashboardPlugin::getWidget()
 {
     SKGTRACEINFUNC(10)
