@@ -51,6 +51,26 @@ public:
      */
     bool setupActions(SKGDocument* iDocument) override;
 
+    /**
+     * The number of dashboard widgets of the plugin.
+     * @return The number of dashboard widgets of the plugin
+     */
+    int getNbDashboardWidgets() override;
+
+    /**
+     * Get a dashboard widget title of the plugin.
+     * @param iIndex the index of the widget
+     * @return The title
+     */
+    QString getDashboardWidgetTitle(int iIndex) override;
+
+    /**
+     * Get a dashboard widget of the plugin.
+     * @param iIndex the index of the widget
+     * @return The dashboard widget of the plugin
+     */
+    SKGBoardWidget* getDashboardWidget(int iIndex) override;
+
     /**
      * The page widget of the plugin.
      * @return The page widget of the plugin
