@@ -21,17 +21,11 @@
  *
  * @author Stephane MANKOWSKI
  */
-#include <qlist.h>
-#include <qstringlist.h>
-#include <qtimer.h>
 
 #include "skgtabpage.h"
-#include "ui_skgdashboardpluginwidget_base.h"
 
-class QMenu;
 class SKGInterfacePlugin;
-class SKGFlowLayout;
-class SKGBoardWidget;
+class SKGDashboardWidget;
 
 /**
  * A dashboard
@@ -89,51 +83,16 @@ public:
      */
     QList<QWidget*> printableWidgets() override;
 
-protected:
-    /**
-     * Event filtering
-     * @param iObject object
-     * @param iEvent event
-     * @return In your reimplementation of this function, if you want to filter the event out, i.e. stop it being handled further, return true; otherwise return false.
-     */
-    bool eventFilter(QObject* iObject, QEvent* iEvent) override;
-
 public Q_SLOTS:
     /**
     * Refresh the content.
      */
     virtual void refresh();
 
-Q_SIGNALS:
-    /**
-     * When an applet id added
-     */
-    void appletAdded(const QString& /*_t1*/);
-
-private Q_SLOTS:
-    void showHeaderMenu(QPoint iPos);
-    void onAddWidget();
-    void onRemoveWidget();
-    void onMoveWidget(int iMove);
-
 private:
     Q_DISABLE_COPY(SKGDashboardPluginWidget)
 
-    void addItem(SKGInterfacePlugin* iDashboard, int iIndex, int iZoom = -10, const QString& iState = QString());
-    void moveItem(int iFrom, int iTo);
-    static SKGBoardWidget* parentBoardWidget(QWidget* iWidget);
-
-    Ui::skgdashboardplugin_base ui{};
-    SKGFlowLayout* m_flowLayout;
-
-    QStringList m_items;
-    QList<SKGBoardWidget*> m_itemsPointers;
-    QMenu* m_menu;
-    QMenu* m_addMenu;
-    QTimer m_timer;
-
-    QPoint m_clickedPoint;
-    QPoint m_lastPoint;
+    SKGDashboardWidget* m_widget;
 };
 
 #endif  // SKGDASHBOARDPLUGINWIDGET_H
