@@ -35,17 +35,17 @@
 QString fixSQL(SKGReport* report, const QString& iSql)
 {
     auto sql = iSql;
-    sql = sql.replace("##PERIOD##", SKGServices::getPeriodWhereClause(report->getPeriod()));
-    sql = sql.replace("##<PERIOD##", SKGServices::getPeriodWhereClause(report->getPeriod(), QStringLiteral("d_date"), QStringLiteral("<")));
-    sql = sql.replace("##>PERIOD##", SKGServices::getPeriodWhereClause(report->getPeriod(), QStringLiteral("d_date"), QStringLiteral(">")));
-    sql = sql.replace("##<=PERIOD##", SKGServices::getPeriodWhereClause(report->getPeriod(), QStringLiteral("d_date"), QStringLiteral("<=")));
-    sql = sql.replace("##>=PERIOD##", SKGServices::getPeriodWhereClause(report->getPeriod(), QStringLiteral("d_date"), QStringLiteral(">=")));
+    sql = sql.replace(QStringLiteral("##PERIOD##"), SKGServices::getPeriodWhereClause(report->getPeriod()));
+    sql = sql.replace(QStringLiteral("##<PERIOD##"), SKGServices::getPeriodWhereClause(report->getPeriod(), QStringLiteral("d_date"), QStringLiteral("<")));
+    sql = sql.replace(QStringLiteral("##>PERIOD##"), SKGServices::getPeriodWhereClause(report->getPeriod(), QStringLiteral("d_date"), QStringLiteral(">")));
+    sql = sql.replace(QStringLiteral("##<=PERIOD##"), SKGServices::getPeriodWhereClause(report->getPeriod(), QStringLiteral("d_date"), QStringLiteral("<=")));
+    sql = sql.replace(QStringLiteral("##>=PERIOD##"), SKGServices::getPeriodWhereClause(report->getPeriod(), QStringLiteral("d_date"), QStringLiteral(">=")));
 
-    sql = sql.replace("##PREVIOUS_PERIOD##", SKGServices::getPeriodWhereClause(report->getPreviousPeriod()));
-    sql = sql.replace("##<PREVIOUS_PERIOD##", SKGServices::getPeriodWhereClause(report->getPreviousPeriod(), QStringLiteral("d_date"), QStringLiteral("<")));
-    sql = sql.replace("##>PREVIOUS_PERIOD##", SKGServices::getPeriodWhereClause(report->getPreviousPeriod(), QStringLiteral("d_date"), QStringLiteral(">")));
-    sql = sql.replace("##<=PREVIOUS_PERIOD##", SKGServices::getPeriodWhereClause(report->getPreviousPeriod(), QStringLiteral("d_date"), QStringLiteral("<=")));
-    sql = sql.replace("##>=PREVIOUS_PERIOD##", SKGServices::getPeriodWhereClause(report->getPreviousPeriod(), QStringLiteral("d_date"), QStringLiteral(">=")));
+    sql = sql.replace(QStringLiteral("##PREVIOUS_PERIOD##"), SKGServices::getPeriodWhereClause(report->getPreviousPeriod()));
+    sql = sql.replace(QStringLiteral("##<PREVIOUS_PERIOD##"), SKGServices::getPeriodWhereClause(report->getPreviousPeriod(), QStringLiteral("d_date"), QStringLiteral("<")));
+    sql = sql.replace(QStringLiteral("##>PREVIOUS_PERIOD##"), SKGServices::getPeriodWhereClause(report->getPreviousPeriod(), QStringLiteral("d_date"), QStringLiteral(">")));
+    sql = sql.replace(QStringLiteral("##<=PREVIOUS_PERIOD##"), SKGServices::getPeriodWhereClause(report->getPreviousPeriod(), QStringLiteral("d_date"), QStringLiteral("<=")));
+    sql = sql.replace(QStringLiteral("##>=PREVIOUS_PERIOD##"), SKGServices::getPeriodWhereClause(report->getPreviousPeriod(), QStringLiteral("d_date"), QStringLiteral(">=")));
     return sql;
 }
 
