@@ -25,9 +25,13 @@
 
 #ifdef SKG_WEBENGINE
 class QWebEngineView;
-#else
+#endif
+#ifdef SKG_WEBKIT
 class QWebView;
 #endif
+#if !defined(SKG_WEBENGINE) && !defined(SKG_WEBKIT)
+class QLabel;
+#endif
 
 
 /**
@@ -114,9 +118,13 @@ private:
     SKGDocument* m_currentBankDocument;
 #ifdef SKG_WEBENGINE
     QWebEngineView* m_mainPage;
-#else
+#endif
+#ifdef SKG_WEBKIT
     QWebView* m_mainPage;
 #endif
+#if !defined(SKG_WEBENGINE) && !defined(SKG_WEBKIT)
+    QLabel* m_mainPage;
+#endif
 };
 
 #endif  // SKGMonthlyPLUGIN_H
