@@ -34,7 +34,8 @@
 #include <qtextstream.h>
 #ifdef SKG_WEBENGINE
 #include <qwebenginepage.h>
-#else
+#endif
+#ifdef SKG_WEBKIT
 #include <qwebframe.h>
 #endif
 #include <qdiriterator.h>
@@ -290,9 +291,13 @@ void SKGMonthlyPluginWidget::onPeriodChanged()
         // Display html report
 #ifdef SKG_WEBENGINE
         ui.kWebView->page()->setHtml(htmlReport, QUrl("file://"));
-#else
+#endif
+#ifdef SKG_WEBKIT
         ui.kWebView->setHtml(htmlReport);
         ui.kWebView->page()->setLinkDelegationPolicy(QWebPage::DelegateAllLinks);
+#endif
+#if !defined(SKG_WEBENGINE) && !defined(SKG_WEBKIT)
+        ui.kWebView->setHtml(htmlReport);
 #endif
     }
 }
@@ -327,7 +332,8 @@ void SKGMonthlyPluginWidget::onPutNewHotStuff()
         QString preview3 = QDir::tempPath() % "/" % templat % "_preview3.png";
 #ifdef SKG_WEBENGINE
         // TODO(SMI): QWebEngine
-#else
+#endif
+#ifdef SKG_WEBKIT
         bool previous = ui.kWebView->blockSignals(true);
         QWebFrame* frame = ui.kWebView->page()->mainFrame();
         frame->setScrollBarValue(Qt::Vertical, frame->scrollBarMaximum(Qt::Vertical));
@@ -340,7 +346,9 @@ void SKGMonthlyPluginWidget::onPutNewHotStuff()
         ui.kWebView->exportInFile(preview1);
         ui.kWebView->blockSignals(previous);
 #endif
-
+#if !defined(SKG_WEBENGINE) && !defined(SKG_WEBKIT)
+        // TODO(SMI): QTextBrowser
+#endif
         // Open dialog
         QPointer<KNS3::UploadDialog> dialog = new KNS3::UploadDialog(KAboutData::applicationData().componentName() % "_monthly.knsrc", this);
 
