@@ -157,9 +157,9 @@ SKGError SKGPrintPlugin::getHtml(QPrinter* iPrinter, QString& oHtml) const
         int pageCopies;
         if (iPrinter->collateCopies()) {
             docCopies = 1;
-            pageCopies = iPrinter->actualNumCopies();
+            pageCopies = iPrinter->copyCount();
         } else {
-            docCopies = iPrinter->actualNumCopies();
+            docCopies = iPrinter->copyCount();
             pageCopies = 1;
         }
         int fromPage = qMin(iPrinter->fromPage(), iPrinter->toPage());
@@ -218,18 +218,25 @@ SKGError SKGPrintPlugin::getHtml(QPrinter* iPrinter, QString& oHtml) const
                                     } else {*/
 #ifdef SKG_WEBENGINE
                                     auto q = qobject_cast< QWebEngineView* >(w);
-#else
+#endif
+#ifdef SKG_WEBKIT
                                     auto q = qobject_cast< QWebView* >(w);
 #endif
-
+#if !defined(SKG_WEBENGINE) && !defined(SKG_WEBKIT)
+                                    auto q = qobject_cast< QTextBrowser* >(w);
+#endif
                                     if (q != nullptr) {
 #ifdef SKG_WEBENGINE
                                         q->page()->toHtml([&](const QString & result) {
                                             html = html % result;
                                         });
                                         qApp->processEvents(QEventLoop::AllEvents, 5000);
-#else
+#endif
+#ifdef SKG_WEBKIT
                                         html = html % q->page()->currentFrame()->toHtml();
+#endif
+#if !defined(SKG_WEBENGINE) && !defined(SKG_WEBKIT)
+                                        html = html % q->toHtml();
 #endif
                                     } else {
                                         // Save palette
@@ -281,7 +288,12 @@ void SKGPrintPlugin::print(QPrinter* iPrinter)
             m_toPrint.page()->print(iPrinter, [](bool) {});
         });
         m_toPrint.setHtml(html, QUrl("file://"));
-#else
+#endif
+#ifdef SKG_WEBKIT
+        m_toPrint.setHtml(html);
+        m_toPrint.print(iPrinter);
+#endif
+#if !defined(SKG_WEBENGINE) && !defined(SKG_WEBKIT)
         m_toPrint.setHtml(html);
         m_toPrint.print(iPrinter);
 #endif
