@@ -24,10 +24,14 @@
 #include <qprinter.h>
 #ifdef SKG_WEBENGINE
 #include <qwebengineview.h>
-#else
+#endif
+#ifdef SKG_WEBKIT
 #include <qwebframe.h>
 #include <qwebview.h>
 #endif
+#if !defined(SKG_WEBENGINE) && !defined(SKG_WEBKIT)
+#include <qtextbrowser.h>
+#endif
 
 #include "skginterfaceplugin.h"
 #include "ui_skgprintpluginwidget_pref.h"
@@ -97,11 +101,14 @@ private:
     QPrinter m_printer;
 #ifdef SKG_WEBENGINE
     QWebEngineView m_toPrint;
-#else
+#endif
+#ifdef SKG_WEBKIT
     QWebView m_toPrint;
 #endif
-
-    Ui::skgprintplugin_pref ui{};
+#if !defined(SKG_WEBENGINE) && !defined(SKG_WEBKIT)
+    QTextEdit m_toPrint;
+#endif
+    Ui::skgprintplugin_pref ui {};
 };
 
 #endif  // SKGPRINTPLUGIN_H
