@@ -89,7 +89,7 @@ void SKGStatisticPlugin::refresh()
                 // Connect actions
                 QMap<QString, QPointer<QAction> > actions = SKGMainPanel::getMainPanel()->getGlobalActions();
                 QStringList keys = actions.keys();
-                for (const auto& k : keys) {
+                for (const auto& k : qAsConst(keys)) {
                     QPointer<QAction> act = actions[k];
                     connect(act.data(), &QAction::triggered, this, &SKGStatisticPlugin::triggerAction);
                 }
@@ -124,7 +124,7 @@ void SKGStatisticPlugin::refresh()
                 m_stats[QStringLiteral("current.app_version")] = KAboutData::applicationData().version();
                 m_stats[QStringLiteral("current.language")] = QLocale::languageToString(QLocale().language());
                 m_stats[QStringLiteral("current.country")] = QLocale::countryToString(QLocale().country());
-                m_stats[QStringLiteral("current.country.code")] = QLocale().name().split("_").at(0);
+                m_stats[QStringLiteral("current.country.code")] = QLocale().name().split(QStringLiteral("_")).at(0);
                 m_stats[QStringLiteral("current.locale")] = QLocale().name();
 
                 // OS
