@@ -789,7 +789,7 @@ SKGError SKGImportPluginCsv::exportFile()
     auto listUUIDs = SKGServices::splitCSVLine(m_exportParameters.value(QStringLiteral("uuid_of_selected_accounts_or_operations")));
 
     QString wc;
-    for (const auto& uuid : listUUIDs) {
+    for (const auto& uuid : qAsConst(listUUIDs)) {
         auto items = SKGServices::splitCSVLine(uuid, '-');
         if (items.at(1) == QStringLiteral("operation")) {
             if (!wc.isEmpty()) {
