@@ -341,7 +341,7 @@ SKGError SKGImportPluginIif::exportFile()
     listOperationsToExport.reserve(listUUIDs.count());
     QStringList listAccountsToExport;
     listAccountsToExport.reserve(listUUIDs.count());
-    for (const auto& uuid : listUUIDs) {
+    for (const auto& uuid : qAsConst(listUUIDs)) {
         if (uuid.endsWith(QLatin1String("-operation"))) {
             listOperationsToExport.push_back(uuid);
         } else if (uuid.endsWith(QLatin1String("-account"))) {
