@@ -47,7 +47,7 @@ SKGImportPluginLedger::SKGImportPluginLedger(QObject* iImporter, const QVariantL
     SKGTRACEINFUNC(10)
     Q_UNUSED(iArg)
 
-    m_importParameters[QStringLiteral("ledger_account_identification")] = "COMPTE,COMPTES,CAPITAUX,ASSETS,LIABILITIES,SAVING";
+    m_importParameters[QStringLiteral("ledger_account_identification")] = QStringLiteral("COMPTE,COMPTES,CAPITAUX,ASSETS,LIABILITIES,SAVING");
 }
 
 SKGImportPluginLedger::~SKGImportPluginLedger()
@@ -69,7 +69,7 @@ SKGError SKGImportPluginLedger::exportFile()
         auto listUUIDs = SKGServices::splitCSVLine(m_exportParameters.value(QStringLiteral("uuid_of_selected_accounts_or_operations")));
 
         QString wc;
-        for (const auto& uuid : listUUIDs) {
+        for (const auto& uuid : qAsConst(listUUIDs)) {
             auto items = SKGServices::splitCSVLine(uuid, '-');
             if (items.at(1) == QStringLiteral("operation")) {
                 if (!wc.isEmpty()) {
@@ -347,7 +347,7 @@ SKGError SKGImportPluginLedger::importFile()
                         for (int i2 = 0; !err && i2 < nb2; ++i2) {
                             auto posting = postingL.at(i2).toElement();
                             auto account = posting.firstChildElement(QStringLiteral("account")).toElement();
-                            auto type = account.firstChildElement(QStringLiteral("name")).toElement().text().split(":")[0].toUpper().trimmed();
+                            auto type = account.firstChildElement(QStringLiteral("name")).toElement().text().split(QStringLiteral(":"))[0].toUpper().trimmed();
 
                             if (isAccount(type)) {
                                 list_porting.insert(0, posting);
@@ -367,7 +367,7 @@ SKGError SKGImportPluginLedger::importFile()
                             auto amount = postamount.firstChildElement(QStringLiteral("amount")).toElement();
                             auto quantity = amount.firstChildElement(QStringLiteral("quantity")).toElement().text().trimmed();
 
-                            auto names = name.split(":");
+                            auto names = name.split(QStringLiteral(":"));
                             QString type;
                             if (names.length() > 1) {
                                 type = names[0].toUpper();
@@ -424,7 +424,7 @@ SKGError SKGImportPluginLedger::importFile()
                                 }
                                 IFOKDO(err, opObj.setComment(note))
                                 IFOKDO(err, opObj.setImported(true))
-                                IFOKDO(err, opObj.setImportID("LEDGER-"))
+                                IFOKDO(err, opObj.setImportID(QStringLiteral("LEDGER-")))
                                 IFOKDO(err, opObj.setStatus(status == QStringLiteral("cleared") ? SKGOperationObject::CHECKED :
                                                             status == QStringLiteral("pending") ? SKGOperationObject::POINTED : SKGOperationObject::NONE))
                                 IFOKDO(err, opObj.save())
