@@ -141,7 +141,7 @@ SKGError SKGImportPluginMny::importFile()
             IFKO(err) return err;
         } else {
             err.setReturnCode(ERR_INSTALL).setMessage(i18nc("Error message",  "The sunriise application is needed for Microsoft Money import but is not installed in '%1'", sunriise_jar));
-            err.setProperty("sunriise");
+            err.setProperty(QStringLiteral("sunriise"));
             return err;
         }
     }
