@@ -63,7 +63,7 @@ QString SKGImportPluginPDF::extract(const QStringList& iLine, const QString& iSy
 
     // Interpret the syntax
     auto items = SKGServices::splitCSVLine(iSyntax, '|', false);
-    for (const auto& item : items) {
+    for (const auto& item : qAsConst(items)) {
         if (item.startsWith(QLatin1String("REGEXPCAP:"))) {
             QRegExp regexp(item.right(item.length() - 10));
             if (output.isEmpty()) {
