@@ -99,6 +99,16 @@ QString SKGBankPlugin::getDashboardWidgetTitle(int iIndex)
 
 SKGBoardWidget* SKGBankPlugin::getDashboardWidget(int iIndex)
 {
+    auto listForFilter = QStringList()
+                         << QStringLiteral("t_name")
+                         << QStringLiteral("t_number")
+                         << QStringLiteral("t_agency_number")
+                         << QStringLiteral("t_agency_address")
+                         << QStringLiteral("t_comment")
+                         << QStringLiteral("t_bookmarked")
+                         << QStringLiteral("t_TYPENLS")
+                         << QStringLiteral("t_BANK")
+                         << QStringLiteral("t_BANK_NUMBER");
     // Get QML mode for dashboard
     KConfigSkeleton* skl = SKGMainPanel::getMainPanel()->getPluginByName(QStringLiteral("Dashboard plugin"))->getPreferenceSkeleton();
     KConfigSkeletonItem* sklItem = skl->findItem(QStringLiteral("qmlmode"));
@@ -111,13 +121,17 @@ SKGBoardWidget* SKGBankPlugin::getDashboardWidget(int iIndex)
         return new SKGHtmlBoardWidget(SKGMainPanel::getMainPanel(), m_currentBankDocument,
                                       getDashboardWidgetTitle(iIndex),
                                       QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("skrooge/html/default/account_table.") % (qml ?  QStringLiteral("qml") :  QStringLiteral("html"))),
-                                      QStringList() << QStringLiteral("v_account_display"), SKGSimplePeriodEdit::PREVIOUS_AND_CURRENT_PERIODS);
+                                      QStringList() << QStringLiteral("v_account_display"),
+                                      SKGSimplePeriodEdit::PREVIOUS_AND_CURRENT_PERIODS,
+                                      listForFilter);
     }
     if (iIndex == 2) {
         auto w = new SKGHtmlBoardWidget(SKGMainPanel::getMainPanel(), m_currentBankDocument,
                                         getDashboardWidgetTitle(iIndex),
                                         QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("skrooge/html/default/bank_table_light.") % (qml ?  QStringLiteral("qml") :  QStringLiteral("html"))),
-                                        QStringList() << QStringLiteral("v_account_display"));
+                                        QStringList() << QStringLiteral("v_account_display"),
+                                        SKGSimplePeriodEdit::NONE,
+                                        listForFilter);
 
         QStringList overlayopen;
         overlayopen.push_back(QStringLiteral("quickopen"));
@@ -135,7 +149,9 @@ SKGBoardWidget* SKGBankPlugin::getDashboardWidget(int iIndex)
     return new SKGHtmlBoardWidget(SKGMainPanel::getMainPanel(), m_currentBankDocument,
                                   getDashboardWidgetTitle(iIndex),
                                   QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("skrooge/html/default/bank_table.") % (qml ?  QStringLiteral("qml") :  QStringLiteral("html"))),
-                                  QStringList() << QStringLiteral("v_account_display"), SKGSimplePeriodEdit::PREVIOUS_AND_CURRENT_PERIODS);
+                                  QStringList() << QStringLiteral("v_account_display"),
+                                  SKGSimplePeriodEdit::PREVIOUS_AND_CURRENT_PERIODS,
+                                  listForFilter);
 }
 
 SKGTabPage* SKGBankPlugin::getWidget()
