@@ -169,7 +169,7 @@ SKGBankPluginWidget::SKGBankPluginWidget(QWidget* iParent, SKGDocumentBank* iDoc
     connect(ui.kView->getView(), &SKGTreeView::selectionChangedDelayed, this, [ = ] {this->onSelectionChanged();});
 
     // Search file list
-    QString listIconFile = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "skrooge/images/logo/l10n/" % QLocale().name().split("_").at(0) % "/list_bank.txt");
+    QString listIconFile = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "skrooge/images/logo/l10n/" % QLocale().name().split(QStringLiteral("_")).at(0) % "/list_bank.txt");
     if (listIconFile.isEmpty()) {
         listIconFile = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("skrooge/images/logo/list_bank.txt"));
     }
@@ -200,6 +200,9 @@ SKGBankPluginWidget::SKGBankPluginWidget(QWidget* iParent, SKGDocumentBank* iDoc
 
         file.close();
     }
+    if(ui.kAccountCreatorIcon->count()<11) {
+        ui.kAccountCreatorIcon->setMaxVisibleItems(ui.kAccountCreatorIcon->count()-1);
+    }
 
     // Set Event filters to catch CTRL+ENTER or SHIFT+ENTER
     this->installEventFilter(this);
