@@ -85,7 +85,7 @@ SKGBudgetPluginWidget::SKGBudgetPluginWidget(QWidget* iParent, SKGDocument* iDoc
                                        Qt::META + Qt::Key_0);
     ui.kView->getShowWidget()->addSeparator();
     ui.kView->getShowWidget()->addItem(QStringLiteral("current"), i18nc("Noun, budget items to display", "Current"), QStringLiteral("view-calendar-whatsnext"),
-                                       QStringLiteral("t_PERIOD>=STRFTIME('%Y-%m', date('now')) OR t_PERIOD=STRFTIME('%Y', date('now'))"),
+                                       QStringLiteral("t_PERIOD>=STRFTIME('%Y-%m', date('now', 'localtime')) OR t_PERIOD=STRFTIME('%Y', date('now', 'localtime'))"),
                                        QStringLiteral("currentMonth"),  // Check when checked
                                        QStringLiteral("none"),       // Uncheck when checked
                                        QLatin1String(""),       // Check when unchecked
@@ -93,14 +93,14 @@ SKGBudgetPluginWidget::SKGBudgetPluginWidget(QWidget* iParent, SKGDocument* iDoc
                                        Qt::META + Qt::Key_1);
     ui.kView->getShowWidget()->addSeparator();
     ui.kView->getShowWidget()->addItem(QStringLiteral("currentYear"), i18nc("Noun, budget items to display", "Current year"), QStringLiteral("view-calendar-month"),
-                                       QStringLiteral("t_PERIOD LIKE STRFTIME('%Y', date('now'))||'%'"),
+                                       QStringLiteral("t_PERIOD LIKE STRFTIME('%Y', date('now', 'localtime'))||'%'"),
                                        QLatin1String(""),
                                        QStringLiteral("none"),
                                        QLatin1String(""),
                                        QStringLiteral("all"),
                                        Qt::META + Qt::Key_3);
     ui.kView->getShowWidget()->addItem(QStringLiteral("currentMonth"), i18nc("Noun, budget items to display", "Current month"), QStringLiteral("view-calendar-week"),
-                                       QStringLiteral("t_PERIOD=STRFTIME('%Y-%m', date('now'))"),
+                                       QStringLiteral("t_PERIOD=STRFTIME('%Y-%m', date('now', 'localtime'))"),
                                        QLatin1String(""),
                                        QStringLiteral("none"),
                                        QLatin1String(""),
@@ -108,14 +108,14 @@ SKGBudgetPluginWidget::SKGBudgetPluginWidget(QWidget* iParent, SKGDocument* iDoc
                                        Qt::META + Qt::Key_2);
     ui.kView->getShowWidget()->addSeparator();
     ui.kView->getShowWidget()->addItem(QStringLiteral("previousYear"), i18nc("Noun, budget items to display", "Previous year"), QStringLiteral("view-calendar-month"),
-                                       QStringLiteral("t_PERIOD LIKE STRFTIME('%Y', date('now','start of year','-1 day'))||'%'"),
+                                       QStringLiteral("t_PERIOD LIKE STRFTIME('%Y', date('now', 'localtime','start of year','-1 day'))||'%'"),
                                        QLatin1String(""),
                                        QStringLiteral("none"),
                                        QLatin1String(""),
                                        QStringLiteral("all"),
                                        Qt::META + Qt::Key_5);
     ui.kView->getShowWidget()->addItem(QStringLiteral("previousMonth"), i18nc("Noun, budget items to display", "Previous month"), QStringLiteral("view-calendar-week"),
-                                       QStringLiteral("t_PERIOD=STRFTIME('%Y-%m', date('now','start of month','-1 day'))"),
+                                       QStringLiteral("t_PERIOD=STRFTIME('%Y-%m', date('now', 'localtime','start of month','-1 day'))"),
                                        QLatin1String(""),
                                        QStringLiteral("none"),
                                        QLatin1String(""),
