@@ -83,11 +83,23 @@ SKGBoardWidget* SKGCalculatorPlugin::getDashboardWidget(int iIndex)
     KConfigSkeleton* skl = SKGMainPanel::getMainPanel()->getPluginByName(QStringLiteral("Dashboard plugin"))->getPreferenceSkeleton();
     KConfigSkeletonItem* sklItem = skl->findItem(QStringLiteral("qmlmode"));
     bool qml = sklItem->property().toBool();
+    auto listForFilter = QStringList()
+                         << QStringLiteral("t_name")
+                         << QStringLiteral("t_number")
+                         << QStringLiteral("t_agency_number")
+                         << QStringLiteral("t_agency_address")
+                         << QStringLiteral("t_comment")
+                         << QStringLiteral("t_bookmarked")
+                         << QStringLiteral("t_TYPENLS")
+                         << QStringLiteral("t_BANK")
+                         << QStringLiteral("t_BANK_NUMBER");
 
     return new SKGHtmlBoardWidget(SKGMainPanel::getMainPanel(), m_currentBankDocument,
                                   getDashboardWidgetTitle(iIndex),
                                   QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("skrooge/html/default/interests.") % (qml ?  QStringLiteral("qml") :  QStringLiteral("html"))),
-                                  QStringList() << QStringLiteral("v_account_display") << QStringLiteral("interest"), SKGSimplePeriodEdit::PREVIOUS_AND_CURRENT_YEARS);
+                                  QStringList() << QStringLiteral("v_account_display") << QStringLiteral("interest"),
+                                  SKGSimplePeriodEdit::PREVIOUS_AND_CURRENT_YEARS,
+                                  listForFilter);
 }
 
 SKGTabPage* SKGCalculatorPlugin::getWidget()
