@@ -85,7 +85,7 @@ bool SKGCategoriesPlugin::setupActions(SKGDocument* iDocument)
     connect(actImportStdCat, &QAction::triggered, this, &SKGCategoriesPlugin::importStandardCategories);
     registerGlobalAction(QStringLiteral("import_standard_categories"), actImportStdCat);
 
-    const auto dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, "skrooge/categories/" % QLocale().name().split("_").at(0), QStandardPaths::LocateDirectory);
+    const auto dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, "skrooge/categories/" % QLocale().name().split(QStringLiteral("_")).at(0), QStandardPaths::LocateDirectory);
     for (const auto& dir : dirs) {
         QDirIterator it(dir, QStringList() << QStringLiteral("*.qif"));
         while (it.hasNext()) {
