@@ -38,7 +38,8 @@
 
 SKGOperationBoardWidgetQml::SKGOperationBoardWidgetQml(QWidget* iParent, SKGDocument* iDocument)
     : SKGHtmlBoardWidget(iParent, iDocument, i18nc("Dashboard widget title", "Income & Expenditure"),
-                         QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("skrooge/html/default/income_vs_expenditure.qml")), QStringList() << QStringLiteral("v_operation")),
+                         QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("skrooge/html/default/income_vs_expenditure.qml")),
+                         QStringList() << QStringLiteral("v_operation")),
       m_periodEdit1(nullptr), m_periodEdit2(nullptr)
 {
     SKGTRACEINFUNC(10)
