@@ -177,7 +177,7 @@ bool SKGOperationPlugin::setupActions(SKGDocument* iDocument)
 
     // ------------
     auto actOpenSuboperations = new QAction(SKGServices::fromTheme(QStringLiteral("split"), overlayopen), i18nc("Verb", "Open sub operations..."), this);
-    actOpenSuboperations->setData(QString("skg://skrooge_operation_plugin/SKGOPERATION_CONSOLIDATED_DEFAULT_PARAMETERS/?title_icon=split&operationTable=v_suboperation_consolidated&operationWhereClause=&title=" % SKGServices::encodeForUrl(i18nc("Noun, a list of items", "Sub operations"))));
+    actOpenSuboperations->setData(QString("skg://skrooge_operation_plugin/SKGOPERATION_CONSOLIDATED_DEFAULT_PARAMETERS/?title_icon=split&operationTable=v_suboperation_consolidated&operationWhereClause=&title=" % SKGServices::encodeForUrl(i18nc("Noun, a list of items", "Sub operations")) % "#" % SKGServices::encodeForUrl(i18nc("Noun, a list of items", "Sub operations"))));
     connect(actOpenSuboperations, &QAction::triggered, SKGMainPanel::getMainPanel(), [ = ]() {
         SKGMainPanel::getMainPanel()->SKGMainPanel::openPage();
     });
@@ -1033,7 +1033,7 @@ void SKGOperationPlugin::onOpenOperations()
                 root.setAttribute(QStringLiteral("currentPage"), QStringLiteral("-1"));
             }
 
-            SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName(QStringLiteral("Skrooge operation plugin")), -1, doc.toString());
+            SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName(QStringLiteral("Skrooge operation plugin")), -1, doc.toString(), view == QStringLiteral("v_suboperation_consolidated") ? i18nc("Noun, a list of items", "Sub operations") : "");
         }
     }
 }
@@ -1216,7 +1216,7 @@ SKGAdviceList SKGOperationPlugin::advice(const QStringList& iIgnoredAdvice)
                 // Get accounts with too much money
                 m_currentBankDocument->concurrentExecuteSelectSqliteOrder("SELECT t_name FROM v_account_display WHERE t_close='N' AND ("
                         // Interest are computed on amount over the limit too, not need to transfer them "(t_maxamount_enabled='Y' AND f_CURRENTAMOUNT>f_CURRENTAMOUNTUNIT*f_maxamount) OR "
-                        "(f_RATE<" % rate % " AND t_type='C' AND f_CURRENTAMOUNT>-2*(SELECT TOTAL(s.f_CURRENTAMOUNT) FROM v_operation_display s WHERE s.rd_account_id=v_account_display.id AND s.t_TYPEEXPENSE='-' AND s.d_DATEMONTH = (SELECT strftime('%Y-%m',date('now','start of month', '-1 MONTH')))))"
+                        "(f_RATE<" % rate % " AND t_type='C' AND f_CURRENTAMOUNT>-2*(SELECT TOTAL(s.f_CURRENTAMOUNT) FROM v_operation_display s WHERE s.rd_account_id=v_account_display.id AND s.t_TYPEEXPENSE='-' AND s.d_DATEMONTH = (SELECT strftime('%Y-%m',date('now', 'localtime','start of month', '-1 MONTH')))))"
                 ")", [ &output, target, rate ](const SKGStringListList & iResult2) {
                     int nb = iResult2.count();
                     QMutex mutex;
@@ -1709,7 +1709,7 @@ void SKGOperationPlugin::onShowOpenWithMenu()
         QStringList attributes;
         auto schema = SKGServices::splitCSVLine(m_currentBankDocument->getDisplaySchemas(modeOperation ? QStringLiteral("operation") : QStringLiteral("suboperation")).at(0).schema);
         attributes.reserve(attributes.count());
-        for (const auto& att : schema) {
+        for (const auto& att : qAsConst(schema)) {
             auto a = SKGServices::splitCSVLine(att, QLatin1Char('|')).value(0);
             if (existingAttributes.contains(a) && !a.endsWith(QLatin1String("_INCOME")) && !a.endsWith(QLatin1String("_EXPENSE")))  {
                 attributes.push_back(a);
@@ -1768,7 +1768,7 @@ void SKGOperationPlugin::onShowOpenWithMenu()
                         root.setAttribute(QStringLiteral("title"), title);
                         root.setAttribute(QStringLiteral("title_icon"), iconName);
 
-                        SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName(QStringLiteral("Skrooge operation plugin")), -1, doc.toString());
+                        SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName(QStringLiteral("Skrooge operation plugin")), -1, doc.toString(), modeOperation ? "" : i18nc("Noun, a list of items", "Sub operations"));
                     });
                 }
             }
