@@ -89,7 +89,7 @@ bool SKGReportPlugin::setupActions(SKGDocument* iDocument)
         auto act = new QAction(SKGServices::fromTheme(QStringLiteral("security-low"), overlayopen), i18nc("Verb", "Open very old operations..."), this);
         act->setData(QString("skg://skrooge_operation_plugin/?title_icon=security-low&title=" %
                              SKGServices::encodeForUrl(i18nc("Noun, a list of items", "Very old operations")) %
-                             "&operationWhereClause=" % SKGServices::encodeForUrl(QStringLiteral("d_date<=(SELECT date('now', '-50 year')) AND d_date<>'0000-00-00'"))));
+                             "&operationWhereClause=" % SKGServices::encodeForUrl(QStringLiteral("d_date<=(SELECT date('now', 'localtime', '-50 year')) AND d_date<>'0000-00-00'"))));
         connect(act, &QAction::triggered, SKGMainPanel::getMainPanel(),  [ = ]() {
             SKGMainPanel::getMainPanel()->openPage();
         });
@@ -101,7 +101,7 @@ bool SKGReportPlugin::setupActions(SKGDocument* iDocument)
         auto act = new QAction(SKGServices::fromTheme(QStringLiteral("security-low"), overlayopen), i18nc("Verb", "Open very far operations in the future..."), this);
         act->setData(QString("skg://skrooge_operation_plugin/?title_icon=security-low&title=" %
                              SKGServices::encodeForUrl(i18nc("Noun, a list of items", "Very far operations in the future")) %
-                             "&operationWhereClause=" % SKGServices::encodeForUrl(QStringLiteral("d_date>=(SELECT date('now', '+50 year'))"))));
+                             "&operationWhereClause=" % SKGServices::encodeForUrl(QStringLiteral("d_date>=(SELECT date('now', 'localtime', '+50 year'))"))));
         connect(act, &QAction::triggered, SKGMainPanel::getMainPanel(),  [ = ]() {
             SKGMainPanel::getMainPanel()->openPage();
         });
@@ -368,7 +368,7 @@ SKGAdviceList SKGReportPlugin::advice(const QStringList& iIgnoredAdvice)
     // Very old operation
     if (!iIgnoredAdvice.contains(QStringLiteral("skgreportplugin_veryold"))) {
         bool exist = false;
-        m_currentBankDocument->existObjects(QStringLiteral("operation"), QStringLiteral("d_date<=(SELECT date('now', '-50 year')) AND d_date<>'0000-00-00'"), exist);
+        m_currentBankDocument->existObjects(QStringLiteral("operation"), QStringLiteral("d_date<=(SELECT date('now', 'localtime', '-50 year')) AND d_date<>'0000-00-00'"), exist);
         if (exist) {
             SKGAdvice ad;
             ad.setUUID(QStringLiteral("skgreportplugin_veryold"));
@@ -385,7 +385,7 @@ SKGAdviceList SKGReportPlugin::advice(const QStringList& iIgnoredAdvice)
     // Very far operation
     if (!iIgnoredAdvice.contains(QStringLiteral("skgreportplugin_veryfar"))) {
         bool exist = false;
-        m_currentBankDocument->existObjects(QStringLiteral("operation"), QStringLiteral("d_date>=(SELECT date('now', '+50 year'))"), exist);
+        m_currentBankDocument->existObjects(QStringLiteral("operation"), QStringLiteral("d_date>=(SELECT date('now', 'localtime', '+50 year'))"), exist);
         if (exist) {
             SKGAdvice ad;
             ad.setUUID(QStringLiteral("skgreportplugin_veryfar"));
