@@ -115,6 +115,7 @@ SKGReportPluginWidget::SKGReportPluginWidget(QWidget* iParent, SKGDocumentBank*
     }
 
     QMenu* graphMenu = ui.kTableWithGraph->getGraphContextualMenu();
+    SKGComboBox* secondColumns = nullptr;
     if (iMinimmumMode && graphMenu != nullptr) {
         graphMenu->addSeparator();
         QList<QCheckBox*> list;
@@ -130,7 +131,13 @@ SKGReportPluginWidget::SKGReportPluginWidget(QWidget* iParent, SKGDocumentBank*
         }
         graphMenu->addSeparator();
         auto act = new QWidgetAction(this);
-        act->setDefaultWidget(ui.kColumns);
+
+        secondColumns = new SKGComboBox(this);
+
+        connect(ui.kColumns, static_cast<void (SKGComboBox::*)(const QString&)>(&SKGComboBox::currentTextChanged), secondColumns, &SKGComboBox::setCurrentText);
+        connect(secondColumns, static_cast<void (SKGComboBox::*)(const QString&)>(&SKGComboBox::currentTextChanged), ui.kColumns, &SKGComboBox::setCurrentText);
+
+        act->setDefaultWidget(secondColumns);
         graphMenu->addAction(act);
 
         graphMenu->addSeparator();
@@ -201,6 +208,9 @@ SKGReportPluginWidget::SKGReportPluginWidget(QWidget* iParent, SKGDocumentBank*
 
     for (const auto& att : qAsConst(m_attsForColumns)) {
         ui.kColumns->addItem(iDocument->getIcon(att), iDocument->getDisplay(att));
+        if (secondColumns) {
+            secondColumns->addItem(iDocument->getIcon(att), iDocument->getDisplay(att));
+        }
     }
 
     for (const auto& att : qAsConst(m_attsForLines)) {
@@ -1001,13 +1011,13 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                         // Create budgeted operations
                         SKGObjectBase::SKGListSKGObjectBase budgets;
                         IFOKDO(err, doc->getObjects(QStringLiteral("v_budget"),
-                                                    "t_PERIOD>STRFTIME('%Y-%m', date('now')) AND "
+                                                    "t_PERIOD>STRFTIME('%Y-%m', date('now', 'localtime')) AND "
                                                     "t_PERIOD<=STRFTIME('%Y-%m', '" % SKGServices::dateToSqlString(lastDate) % "')", budgets));
                         int nbBudgets = budgets.count();
                         if (nbBudgets != 0) {
                             // Get most active account
                             SKGStringListList list;
-                            err = doc->executeSelectSqliteOrder(QStringLiteral("SELECT  rd_account_id, r_category_id FROM v_suboperation_consolidated WHERE d_date>date('now', '-3 month') group by r_category_id, rd_account_id order by count(rd_account_id) DESC"), list);
+                            err = doc->executeSelectSqliteOrder(QStringLiteral("SELECT  rd_account_id, r_category_id FROM v_suboperation_consolidated WHERE d_date>date('now', 'localtime', '-3 month') group by r_category_id, rd_account_id order by count(rd_account_id) DESC"), list);
                             int nbmap = list.count();
                             if (!err && nbmap >= 2) {
                                 // Build map
@@ -1118,7 +1128,7 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                 }
 
                 // Limit size of the result
-                condition = '(' % condition % ") AND (d_date>(SELECT date('now', '-50 year')) OR d_date='0000') AND d_date<(SELECT date('now', '+50 year'))";
+                condition = '(' % condition % ") AND (d_date>(SELECT date('now', 'localtime', '-50 year')) OR d_date='0000') AND d_date<(SELECT date('now', 'localtime', '+50 year'))";
 
                 QString coef;
                 if (ui.kCorrectedBy->currentIndex() > 0 && mode != 3) {
