@@ -585,7 +585,7 @@ void SKGSearchPluginWidget::open(const SKGRuleObject& iRule, OpenMode iMode)
     if (iMode == TABLE) {
         root.setAttribute(QStringLiteral("operationTable"), QStringLiteral("v_suboperation_consolidated"));
         root.setAttribute(QStringLiteral("currentPage"), QStringLiteral("-1"));
-        SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName(QStringLiteral("Skrooge operation plugin")), -1, doc.toString());
+        SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName(QStringLiteral("Skrooge operation plugin")), -1, doc.toString(), i18nc("Noun, a list of items", "Sub operations"));
     } else {
         root.setAttribute(QStringLiteral("period"), QStringLiteral("0"));
         SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName(QStringLiteral("Skrooge report plugin")), -1, doc.toString());
