@@ -106,10 +106,20 @@ SKGBoardWidget* SKGUnitPlugin::getDashboardWidget(int iIndex)
     KConfigSkeletonItem* sklItem = skl->findItem(QStringLiteral("qmlmode"));
     bool qml = sklItem->property().toBool();
 
+    auto listForFilter = QStringList() << QStringLiteral("t_name")
+                         << QStringLiteral("t_symbol")
+                         << QStringLiteral("t_country")
+                         << QStringLiteral("t_type")
+                         << QStringLiteral("t_internet_code")
+                         << QStringLiteral("t_source")
+                         << QStringLiteral("t_bookmarked");
+
     return new SKGHtmlBoardWidget(SKGMainPanel::getMainPanel(), m_currentBankDocument,
                                   getDashboardWidgetTitle(iIndex),
                                   QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("skrooge/html/default/portfolio.") % (qml ?  QStringLiteral("qml") :  QStringLiteral("html"))),
-                                  QStringList() << QStringLiteral("v_operation_display"));
+                                  QStringList() << QStringLiteral("v_operation_display"),
+                                  SKGSimplePeriodEdit::NONE,
+                                  listForFilter);
 }
 
 void SKGUnitPlugin::refresh()
@@ -380,7 +390,7 @@ SKGAdviceList SKGUnitPlugin::advice(const QStringList& iIgnoredAdvice)
 
     // Shares not downloaded
     if (!iIgnoredAdvice.contains(QStringLiteral("skgunitplugin_notdownloaded"))) {
-        m_currentBankDocument->executeSelectSqliteOrder(QStringLiteral("SELECT t_name, t_internet_code from unit WHERE t_internet_code<>'' AND (julianday('now')-(SELECT MAX(julianday(d_date)) FROM unitvalue WHERE rd_unit_id=unit.id ))>30 OR NOT EXISTS (SELECT 1 FROM unitvalue WHERE unitvalue.rd_unit_id=unit.id)"), result);
+        m_currentBankDocument->executeSelectSqliteOrder(QStringLiteral("SELECT t_name, t_internet_code from unit WHERE t_internet_code<>'' AND (julianday('now', 'localtime')-(SELECT MAX(julianday(d_date)) FROM unitvalue WHERE rd_unit_id=unit.id ))>30 OR NOT EXISTS (SELECT 1 FROM unitvalue WHERE unitvalue.rd_unit_id=unit.id)"), result);
         nb = result.count();
         SKGAdvice::SKGAdviceActionList autoCorrections;
         autoCorrections.reserve(nb);
@@ -492,7 +502,7 @@ SKGAdviceList SKGUnitPlugin::advice(const QStringList& iIgnoredAdvice)
 
     // Unit with very old values
     if (!iIgnoredAdvice.contains(QStringLiteral("skgunitplugin_veryold"))) {
-        m_currentBankDocument->executeSelectSqliteOrder(QStringLiteral("SELECT t_name from unit WHERE (SELECT COUNT(*) FROM unitvalue WHERE unitvalue.rd_unit_id=unit.id)>1 AND EXISTS (SELECT 1 FROM unitvalue WHERE unitvalue.rd_unit_id=unit.id AND unitvalue.d_date<=(SELECT date('now', '-50 year')))"), result);
+        m_currentBankDocument->executeSelectSqliteOrder(QStringLiteral("SELECT t_name from unit WHERE (SELECT COUNT(*) FROM unitvalue WHERE unitvalue.rd_unit_id=unit.id)>1 AND EXISTS (SELECT 1 FROM unitvalue WHERE unitvalue.rd_unit_id=unit.id AND unitvalue.d_date<=(SELECT date('now', 'localtime', '-50 year')))"), result);
         nb = result.count();
         SKGAdvice::SKGAdviceActionList autoCorrections;
         autoCorrections.reserve(nb);
