@@ -352,7 +352,7 @@ void SKGUnitPluginWidget::onSelectionChanged()
     SKGStringListList table;
     getDocument()->getConsolidatedView(QStringLiteral("v_unitvalue_display"), QStringLiteral("d_date"), QStringLiteral("t_UNIT"),
                                        m_unitValueGraphCmb->currentIndex() == 0 ? QStringLiteral("f_quantity") : QStringLiteral("f_AMOUNTOWNED"),
-                                       QStringLiteral("TOTAL"), wc % " AND d_date>(SELECT date('now', '-50 year')) AND d_date<(SELECT date('now', '+50 year'))", table, QLatin1String(""));
+                                       QStringLiteral("TOTAL"), wc % " AND d_date>(SELECT date('now', 'localtime', '-50 year')) AND d_date<(SELECT date('now', 'localtime', '+50 year'))", table, QLatin1String(""));
 
     SKGServices::SKGUnitInfo primaryUnit = qobject_cast<SKGDocumentBank*>(getDocument())->getPrimaryUnit();
     SKGServices::SKGUnitInfo secondaryUnit = qobject_cast<SKGDocumentBank*>(getDocument())->getSecondaryUnit();
