@@ -40,7 +40,7 @@ tempDir='/data'
 
 class Releasor(object):
     def __init__(self, args):
-        self.ubuntuVersions=['focal', 'groovy']
+        self.ubuntuVersions=['focal', 'groovy', 'hirsute']
         self.workdingDir=os.path.join(tempDir, 'skrooge-release_' + args.version)
         print("# Working directory :" + self.workdingDir)    
         if args.version.endswith(".0") or args.stable:
@@ -322,12 +322,12 @@ class Releasor(object):
             print('#   Get snapcraft.yaml from local path')
             cmd = ['cp', os.path.join(localPath, 'snapcraft.yaml'), '.']
         else:
-            cmd = ['wget', '-c', '-nv', 'https://cgit.kde.org/skrooge.git/plain/snapcraft.yaml']
+            cmd = ['wget', '-c', '-nv', 'https://invent.kde.org/office/skrooge/-/raw/master/snapcraft.yaml']
         self.logfile.write('### '+' '.join(cmd)+'\n')                
         rc = subprocess.call(cmd, stdout=self.logfile, stderr=self.logfile)       
         if rc == 0:
             for line in fileinput.input(['snapcraft.yaml'], inplace=True):
-                print(line.replace('version: "X.X.X"', 'version: "'+args.version+'"').replace('source: XXX', 'source: '+localPath if args.fromlocal else 'source: git://anongit.kde.org/skrooge.git'), end='')
+                print(line.replace('version: "X.X.X"', 'version: "'+args.version+'"').replace('source: XXX', 'source: '+localPath if args.fromlocal else 'source: https://invent.kde.org/office/skrooge.git'), end='')
                 
             cmd = ['snapcraft']
             self.logfile.write('### '+' '.join(cmd)+'\n')                
