@@ -203,7 +203,7 @@ QVariant SKGObjectModel::headerData(int section, Qt::Orientation orientation, in
     _SKGTRACEINFUNC(10)
 
     if (orientation == Qt::Horizontal) {
-        if (role == Qt::DisplayRole) {
+        if (role == Qt::DisplayRole || role == Qt::ToolTipRole) {
             QString att;
             if (section >= 0 && section < m_listAttibutes.count()) {
                 att = m_listAttibutes[section];
@@ -212,7 +212,7 @@ QVariant SKGObjectModel::headerData(int section, Qt::Orientation orientation, in
             }
 
             if (att == QStringLiteral("t_bookmarked") || att == QStringLiteral("i_NBRECURRENT") || att == QStringLiteral("t_status") || att == QStringLiteral("t_close") || att == QStringLiteral("t_imported")) {
-                return "";
+                return (role == Qt::ToolTipRole) ? SKGObjectModelBase::headerData(section, orientation, Qt::DisplayRole) : "";
             }
         }
     }
