@@ -276,11 +276,11 @@ SKGError SKGBudgetObject::createAutomaticBudget(SKGDocumentBank* iDocument, int
     if (!err && (iDocument != nullptr)) {
         SKGStringListList listTmp;
         QString sql = "SELECT t_REALCATEGORY, COUNT(TOT),"
-                      "100*COUNT(TOT)/((CASE WHEN STRFTIME('%Y', date('now'))<>'" % baseYear % "' THEN 12 ELSE STRFTIME('%m', date('now'))-1 END)-" %
+                      "100*COUNT(TOT)/((CASE WHEN STRFTIME('%Y', date('now', 'localtime'))<>'" % baseYear % "' THEN 12 ELSE STRFTIME('%m', date('now', 'localtime'))-1 END)-" %
                       SKGServices::intToString(fistMonth) % "+1) AS CPOUR,"
                       "ROUND(TOTAL(TOT)/COUNT(TOT)), MAX(MONTH), TOTAL(TOT) FROM ("
                       "SELECT t_REALCATEGORY, STRFTIME('%m', d_date) AS MONTH, TOTAL(f_REALCURRENTAMOUNT) AS TOT "
-                      "FROM v_suboperation_consolidated WHERE i_group_id = 0 AND d_DATEYEAR = '" % baseYear % "' AND d_DATEMONTH<STRFTIME('%Y-%m', date('now')) "
+                      "FROM v_suboperation_consolidated WHERE i_group_id = 0 AND d_DATEYEAR = '" % baseYear % "' AND d_DATEMONTH<STRFTIME('%Y-%m', date('now', 'localtime')) "
                       "GROUP BY t_REALCATEGORY, d_DATEMONTH"
                       ") GROUP BY t_REALCATEGORY ORDER BY COUNT(TOT) DESC, (MAX(TOT)-MIN(TOT))/ABS(ROUND(TOTAL(TOT)/COUNT(TOT))) ASC, ROUND(TOTAL(TOT)/COUNT(TOT)) ASC";
         err = iDocument->executeSelectSqliteOrder(sql, listTmp);
