@@ -99,7 +99,11 @@ QVariantList SKGReportBank::getInterests()
             // Build display
             int year = SKGServices::periodToDate(getPeriod()).year();
             SKGObjectBase::SKGListSKGObjectBase objs;
-            SKGError err = doc->getObjects(QStringLiteral("v_account"), QStringLiteral("t_close='N' AND EXISTS(select 1 from interest where interest.rd_account_id=v_account.id) ORDER BY t_name"), objs);
+            auto sqlFilter = getSqlFilter();
+            if (sqlFilter.isEmpty()) {
+                sqlFilter = QStringLiteral("1=1");
+            }
+            SKGError err = doc->getObjects(QStringLiteral("v_account"), "(" % sqlFilter % QStringLiteral(") AND t_close='N' AND EXISTS(select 1 from interest where interest.rd_account_id=v_account.id) ORDER BY t_name"), objs);
             IFOK(err) {
                 int nb = objs.count();
                 table.reserve(nb + 2);
@@ -174,7 +178,11 @@ QVariantList SKGReportBank::getPortfolio()
 
                 // Get list of operations
                 SKGObjectBase::SKGListSKGObjectBase objs;
-                SKGError err = doc->getObjects(QStringLiteral("v_operation_display"), "d_date<'" % SKGServices::dateToSqlString(date) % "' AND rc_unit_id IN (SELECT id FROM v_unit_display WHERE t_type='S' AND f_QUANTITYOWNED>0.01) ORDER BY t_UNIT", objs);
+                auto sqlFilter = getSqlFilter();
+                if (sqlFilter.isEmpty()) {
+                    sqlFilter = QStringLiteral("1=1");
+                }
+                SKGError err = doc->getObjects(QStringLiteral("v_operation_display"), "d_date<'" % SKGServices::dateToSqlString(date) % "' AND rc_unit_id IN (SELECT id FROM v_unit_display WHERE t_type='S' AND (" % sqlFilter % ") AND f_QUANTITYOWNED>0.01) ORDER BY t_UNIT", objs);
                 int nb = objs.count();
                 if (!err && nb > 0) {
                     table.reserve(nb + 1);
@@ -317,7 +325,11 @@ QVariantList SKGReportBank::getAccountTable()
                 SKGServices::SKGUnitInfo primary = doc->getPrimaryUnit();
 
                 SKGObjectBase::SKGListSKGObjectBase accounts;
-                SKGError err = doc->getObjects(QStringLiteral("v_account"), QStringLiteral("1=1 ORDER BY t_TYPENLS, t_BANK, t_name"), accounts);
+                auto sqlFilter = getSqlFilter();
+                if (sqlFilter.isEmpty()) {
+                    sqlFilter = QStringLiteral("1=1");
+                }
+                SKGError err = doc->getObjects(QStringLiteral("v_account"), sqlFilter + QStringLiteral(" ORDER BY t_TYPENLS, t_BANK, t_name"), accounts);
                 IFOK(err) {
                     table.push_back(QVariantList() << "sum" << doc->getDisplay(QStringLiteral("t_ACCOUNT")) << QLocale().toString(date1, QLocale::ShortFormat) << QLocale().toString(date2, QLocale::ShortFormat) <<
                                     "%" << QLocale().toString(date3, QLocale::ShortFormat) << QLocale().toString(date2, QLocale::ShortFormat) << "%");
@@ -404,7 +416,11 @@ QVariantList SKGReportBank::getBankTable()
                 SKGServices::SKGUnitInfo primary = doc->getPrimaryUnit();
 
                 SKGObjectBase::SKGListSKGObjectBase accounts;
-                SKGError err = doc->getObjects(QStringLiteral("v_account"), QStringLiteral("1=1 ORDER BY t_BANK"), accounts);
+                auto sqlFilter = getSqlFilter();
+                if (sqlFilter.isEmpty()) {
+                    sqlFilter = QStringLiteral("1=1");
+                }
+                SKGError err = doc->getObjects(QStringLiteral("v_account"), sqlFilter + QStringLiteral(" ORDER BY t_BANK"), accounts);
                 IFOK(err) {
                     table.push_back(QVariantList() << "sum" << doc->getDisplay(QStringLiteral("t_BANK")) << QLocale().toString(date1, QLocale::ShortFormat) << QLocale().toString(date2, QLocale::ShortFormat) <<
                                     "%" << QLocale().toString(date3, QLocale::ShortFormat) << QLocale().toString(date2, QLocale::ShortFormat) << "%");
@@ -480,7 +496,7 @@ QVariantList SKGReportBank::getScheduledOperations()
         SKGObjectBase::SKGListSKGObjectBase objs;
         auto scheduled_operation_days_max = m_parameters.value(QStringLiteral("scheduled_operation_days_max"), QStringLiteral("30")).toString();
         SKGError err = m_document->getObjects(QStringLiteral("v_recurrentoperation_display"),
-                                              QStringLiteral("i_nb_times!=0 AND d_date<=date('now','+") + scheduled_operation_days_max + " day') ORDER BY d_date", objs);
+                                              QStringLiteral("i_nb_times!=0 AND d_date<=date('now', 'localtime','+") + scheduled_operation_days_max + " day') ORDER BY d_date", objs);
         QDate d = QDate::currentDate().addDays(SKGServices::stringToInt(scheduled_operation_days_max));
         QString dateFormatShort = QLocale::system().dateFormat(QLocale::ShortFormat);
         IFOK(err) {
