@@ -425,27 +425,27 @@ QString SKGRuleObject::getDisplayForOperator(const QString& iOperator, const QSt
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "=#ATT2# as date with format #DF#").replace(QStringLiteral("#ATT2#"), iAtt2).replace(QStringLiteral("#DF#"), iParam2);
     } else if (output == QStringLiteral("#ATT#=todate(WORD(#ATT2#,#V1S#),'#DF#')")) {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "=word(#ATT2#,#V1S#) as date with format #DF#").replace(QStringLiteral("#ATT2#"), iAtt2).replace(QStringLiteral("#V1S#"), iParam1).replace(QStringLiteral("#DF#"), iParam2);
-    } else if (output == QStringLiteral("STRFTIME('%Y-%m',#ATT#)=STRFTIME('%Y-%m',date('now'))")) {
+    } else if (output == QStringLiteral("STRFTIME('%Y-%m',#ATT#)=STRFTIME('%Y-%m',date('now', 'localtime'))")) {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in current month");
-    } else if (output == QStringLiteral("STRFTIME('%Y-%m',#ATT#)=STRFTIME('%Y-%m',date('now','start of month','-1 month'))")) {
+    } else if (output == QStringLiteral("STRFTIME('%Y-%m',#ATT#)=STRFTIME('%Y-%m',date('now', 'localtime','start of month','-1 month'))")) {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in previous month");
-    } else if (output == QStringLiteral("STRFTIME('%Y',#ATT#)=STRFTIME('%Y',date('now'))")) {
+    } else if (output == QStringLiteral("STRFTIME('%Y',#ATT#)=STRFTIME('%Y',date('now', 'localtime'))")) {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in current year");
-    } else if (output == QStringLiteral("STRFTIME('%Y',#ATT#)=STRFTIME('%Y',date('now','start of month','-1 year'))")) {
+    } else if (output == QStringLiteral("STRFTIME('%Y',#ATT#)=STRFTIME('%Y',date('now', 'localtime','start of month','-1 year'))")) {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in previous year");
-    } else if (output == QStringLiteral("#ATT#>date('now','-30 day') AND #ATT#<=date('now')")) {
+    } else if (output == QStringLiteral("#ATT#>date('now', 'localtime','-30 day') AND #ATT#<=date('now', 'localtime')")) {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in last 30 days");
-    } else if (output == QStringLiteral("#ATT#>date('now','-3 month') AND #ATT#<=date('now')")) {
+    } else if (output == QStringLiteral("#ATT#>date('now', 'localtime','-3 month') AND #ATT#<=date('now', 'localtime')")) {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in last 3 months");
-    } else if (output == QStringLiteral("#ATT#>date('now','-6 month') AND #ATT#<=date('now')")) {
+    } else if (output == QStringLiteral("#ATT#>date('now', 'localtime','-6 month') AND #ATT#<=date('now', 'localtime')")) {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in last 6 months");
-    } else if (output == QStringLiteral("#ATT#>date('now','-12 month') AND #ATT#<=date('now')")) {
+    } else if (output == QStringLiteral("#ATT#>date('now', 'localtime','-12 month') AND #ATT#<=date('now', 'localtime')")) {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in last 12 months");
-    } else if (output == QStringLiteral("#ATT#>date('now','-2 year') AND #ATT#<=date('now')")) {
+    } else if (output == QStringLiteral("#ATT#>date('now', 'localtime','-2 year') AND #ATT#<=date('now', 'localtime')")) {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in last 2 years");
-    } else if (output == QStringLiteral("#ATT#>date('now','-3 year') AND #ATT#<=date('now')")) {
+    } else if (output == QStringLiteral("#ATT#>date('now', 'localtime','-3 year') AND #ATT#<=date('now', 'localtime')")) {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in last 3 years");
-    } else if (output == QStringLiteral("#ATT#>date('now','-5 year') AND #ATT#<=date('now')")) {
+    } else if (output == QStringLiteral("#ATT#>date('now', 'localtime','-5 year') AND #ATT#<=date('now', 'localtime')")) {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in last 5 years");
     } else if (output == QStringLiteral("ABS(TOTAL(#ATT#))#OP##V1#,ABS(TOTAL(#ATT#)), #V1#, '#V2S#'")) {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "If total(#ATT#)#OP##V1# then send '#V2S#'").replace(QStringLiteral("#V1#"), iParam1).replace(QStringLiteral("#V2S#"), iParam2).replace(QStringLiteral("#OP#"), iAtt2);
@@ -543,27 +543,27 @@ QString SKGRuleObject::getToolTipForOperator(const QString& iOperator)
         output = i18nc("Help for a condition", "To set the date attribute with the value of another attribute");
     } else if (output == QStringLiteral("#ATT#=todate(WORD(#ATT2#,#V1S#),'#DF#')")) {
         output = i18nc("Help for a condition", "To set the date attribute with a word of another attribute converted in date format");
-    } else if (output == QStringLiteral("STRFTIME('%Y-%m',#ATT#)=STRFTIME('%Y-%m',date('now'))")) {
+    } else if (output == QStringLiteral("STRFTIME('%Y-%m',#ATT#)=STRFTIME('%Y-%m',date('now', 'localtime'))")) {
         output = i18nc("Help for a condition", "To find out if the date of the operation is today");
-    } else if (output == QStringLiteral("STRFTIME('%Y-%m',#ATT#)=STRFTIME('%Y-%m',date('now','start of month','-1 month'))")) {
+    } else if (output == QStringLiteral("STRFTIME('%Y-%m',#ATT#)=STRFTIME('%Y-%m',date('now', 'localtime','start of month','-1 month'))")) {
         output = i18nc("Help for a condition", "To find out if the date of the operation is in previous month");
-    } else if (output == QStringLiteral("STRFTIME('%Y',#ATT#)=STRFTIME('%Y',date('now'))")) {
+    } else if (output == QStringLiteral("STRFTIME('%Y',#ATT#)=STRFTIME('%Y',date('now', 'localtime'))")) {
         output = i18nc("Help for a condition", "To find out if the date of the operation is in current year");
-    } else if (output == QStringLiteral("STRFTIME('%Y',#ATT#)=STRFTIME('%Y',date('now','start of month','-1 year'))")) {
+    } else if (output == QStringLiteral("STRFTIME('%Y',#ATT#)=STRFTIME('%Y',date('now', 'localtime','start of month','-1 year'))")) {
         output = i18nc("Help for a condition", "To find out if the date of the operation is in previous year");
-    } else if (output == QStringLiteral("#ATT#>date('now','-30 day') AND #ATT#<=date('now')")) {
+    } else if (output == QStringLiteral("#ATT#>date('now', 'localtime','-30 day') AND #ATT#<=date('now', 'localtime')")) {
         output = i18nc("Help for a condition", "To find out if the date of the operation is in last 30 days");
-    } else if (output == QStringLiteral("#ATT#>date('now','-3 month') AND #ATT#<=date('now')")) {
+    } else if (output == QStringLiteral("#ATT#>date('now', 'localtime','-3 month') AND #ATT#<=date('now', 'localtime')")) {
         output = i18nc("Help for a condition", "To find out if the date of the operation is in last 3 months");
-    } else if (output == QStringLiteral("#ATT#>date('now','-6 month') AND #ATT#<=date('now')")) {
+    } else if (output == QStringLiteral("#ATT#>date('now', 'localtime','-6 month') AND #ATT#<=date('now', 'localtime')")) {
         output = i18nc("Help for a condition", "To find out if the date of the operation is in last 6 months");
-    } else if (output == QStringLiteral("#ATT#>date('now','-12 month') AND #ATT#<=date('now')")) {
+    } else if (output == QStringLiteral("#ATT#>date('now', 'localtime','-12 month') AND #ATT#<=date('now', 'localtime')")) {
         output = i18nc("Help for a condition", "To find out if the date of the operation is in last 12 months");
-    } else if (output == QStringLiteral("#ATT#>date('now','-2 year') AND #ATT#<=date('now')")) {
+    } else if (output == QStringLiteral("#ATT#>date('now', 'localtime','-2 year') AND #ATT#<=date('now', 'localtime')")) {
         output = i18nc("Help for a condition", "To find out if the date of the operation is in last 2 years");
-    } else if (output == QStringLiteral("#ATT#>date('now','-3 year') AND #ATT#<=date('now')")) {
+    } else if (output == QStringLiteral("#ATT#>date('now', 'localtime','-3 year') AND #ATT#<=date('now', 'localtime')")) {
         output = i18nc("Help for a condition", "To find out if the date of the operation is in last 3 years");
-    } else if (output == QStringLiteral("#ATT#>date('now','-5 year') AND #ATT#<=date('now')")) {
+    } else if (output == QStringLiteral("#ATT#>date('now', 'localtime','-5 year') AND #ATT#<=date('now', 'localtime')")) {
         output = i18nc("Help for a condition", "To find out if the date of the operation is in last 5 years");
     }
 
@@ -645,17 +645,17 @@ QStringList SKGRuleObject::getListOfOperators(SKGServices::AttributeType iAttrib
         }
 
         if (iAttributeType == SKGServices::DATE) {
-            output.push_back(QStringLiteral("STRFTIME('%Y-%m',#ATT#)=STRFTIME('%Y-%m',date('now'))"));
-            output.push_back(QStringLiteral("STRFTIME('%Y-%m',#ATT#)=STRFTIME('%Y-%m',date('now','start of month','-1 month'))"));
-            output.push_back(QStringLiteral("STRFTIME('%Y',#ATT#)=STRFTIME('%Y',date('now'))"));
-            output.push_back(QStringLiteral("STRFTIME('%Y',#ATT#)=STRFTIME('%Y',date('now','start of month','-1 year'))"));
-            output.push_back(QStringLiteral("#ATT#>date('now','-30 day') AND #ATT#<=date('now')"));
-            output.push_back(QStringLiteral("#ATT#>date('now','-3 month') AND #ATT#<=date('now')"));
-            output.push_back(QStringLiteral("#ATT#>date('now','-6 month') AND #ATT#<=date('now')"));
-            output.push_back(QStringLiteral("#ATT#>date('now','-12 month') AND #ATT#<=date('now')"));
-            output.push_back(QStringLiteral("#ATT#>date('now','-2 year') AND #ATT#<=date('now')"));
-            output.push_back(QStringLiteral("#ATT#>date('now','-3 year') AND #ATT#<=date('now')"));
-            output.push_back(QStringLiteral("#ATT#>date('now','-5 year') AND #ATT#<=date('now')"));
+            output.push_back(QStringLiteral("STRFTIME('%Y-%m',#ATT#)=STRFTIME('%Y-%m',date('now', 'localtime'))"));
+            output.push_back(QStringLiteral("STRFTIME('%Y-%m',#ATT#)=STRFTIME('%Y-%m',date('now', 'localtime','start of month','-1 month'))"));
+            output.push_back(QStringLiteral("STRFTIME('%Y',#ATT#)=STRFTIME('%Y',date('now', 'localtime'))"));
+            output.push_back(QStringLiteral("STRFTIME('%Y',#ATT#)=STRFTIME('%Y',date('now', 'localtime','start of month','-1 year'))"));
+            output.push_back(QStringLiteral("#ATT#>date('now', 'localtime','-30 day') AND #ATT#<=date('now', 'localtime')"));
+            output.push_back(QStringLiteral("#ATT#>date('now', 'localtime','-3 month') AND #ATT#<=date('now', 'localtime')"));
+            output.push_back(QStringLiteral("#ATT#>date('now', 'localtime','-6 month') AND #ATT#<=date('now', 'localtime')"));
+            output.push_back(QStringLiteral("#ATT#>date('now', 'localtime','-12 month') AND #ATT#<=date('now', 'localtime')"));
+            output.push_back(QStringLiteral("#ATT#>date('now', 'localtime','-2 year') AND #ATT#<=date('now', 'localtime')"));
+            output.push_back(QStringLiteral("#ATT#>date('now', 'localtime','-3 year') AND #ATT#<=date('now', 'localtime')"));
+            output.push_back(QStringLiteral("#ATT#>date('now', 'localtime','-5 year') AND #ATT#<=date('now', 'localtime')"));
         }
     } else if (iType == ALARM) {
         output.push_back(QStringLiteral("ABS(TOTAL(#ATT#))#OP##V1#,ABS(TOTAL(#ATT#)), #V1#, '#V2S#'"));
