@@ -265,8 +265,8 @@ void SKGBoardWidget::setMainWidget(QWidget* iWidget)
 
 void SKGBoardWidget::insertAction(int iPos, QAction* iAction)
 {
-    auto l = m_menu->actions();
-    m_menu->insertAction(l[iPos], iAction);
+    auto l = getMenu()->actions();
+    getMenu()->insertAction(l[iPos], iAction);
 
     // Change icon
     if (!iAction->isCheckable() && !iAction->isSeparator()) {
@@ -274,14 +274,25 @@ void SKGBoardWidget::insertAction(int iPos, QAction* iAction)
     }
 }
 
-void SKGBoardWidget::addAction(QAction* iAction)
+QMenu* SKGBoardWidget::getMenu()
 {
     if (m_menu == nullptr) {
         m_menu = new QMenu(this);
         m_toolButton->show();
         m_toolButton->setMenu(m_menu);
     }
-    m_menu->addAction(iAction);
+
+    return m_menu;
+}
+
+void SKGBoardWidget::addMenu(QMenu* iMenu)
+{
+    getMenu()->addMenu(iMenu);
+}
+
+void SKGBoardWidget::addAction(QAction* iAction)
+{
+    getMenu()->addAction(iAction);
 
     // Change icon
     if (!iAction->isCheckable() && !iAction->isSeparator()) {
