@@ -32,14 +32,15 @@
 
 #include <klocalizedstring.h>
 #include <kcolorscheme.h>
+#include <klineedit.h>
 
 #include "skgdocument.h"
 #include "skgmainpanel.h"
 #include "skgreport.h"
 #include "skgtraces.h"
 
-SKGHtmlBoardWidget::SKGHtmlBoardWidget(QWidget* iParent, SKGDocument* iDocument, const QString& iTitle, const QString& iTemplate, QStringList  iTablesRefreshing, SKGSimplePeriodEdit::Modes iOptions)
-    : SKGBoardWidget(iParent, iDocument, iTitle), m_Quick(nullptr), m_Report(iDocument->getReport()),  m_Text(nullptr), m_Template(iTemplate), m_TablesRefreshing(std::move(iTablesRefreshing)), m_refreshNeeded(false), m_period(nullptr)
+SKGHtmlBoardWidget::SKGHtmlBoardWidget(QWidget* iParent, SKGDocument* iDocument, const QString& iTitle, const QString& iTemplate, QStringList  iTablesRefreshing, SKGSimplePeriodEdit::Modes iOptions, const QStringList& iAttributesForFilter)
+    : SKGBoardWidget(iParent, iDocument, iTitle), m_Quick(nullptr), m_Report(iDocument->getReport()),  m_Text(nullptr), m_Template(iTemplate), m_TablesRefreshing(std::move(iTablesRefreshing)), m_refreshNeeded(false), m_period(nullptr), m_filter(nullptr), m_attributes(iAttributesForFilter)
 {
     SKGTRACEINFUNC(10)
     // Create menu
@@ -65,6 +66,17 @@ SKGHtmlBoardWidget::SKGHtmlBoardWidget(QWidget* iParent, SKGDocument* iDocument,
 
         addAction(periodEditWidget);
     }
+    if (m_attributes.count()) {
+        setContextMenuPolicy(Qt::ActionsContextMenu);
+
+        m_filter = new KLineEdit(this);
+        m_filter->setPlaceholderText(i18nc("A place holder for a filter field", "Filter"));
+
+        auto filterEditWidget = new QWidgetAction(this);
+        filterEditWidget->setDefaultWidget(m_filter);
+
+        addAction(filterEditWidget);
+    }
 
     // Enrich with tips of the day
     m_Report->setTipsOfDay(SKGMainPanel::getMainPanel()->getTipsOfDay());
@@ -91,6 +103,7 @@ SKGHtmlBoardWidget::SKGHtmlBoardWidget(QWidget* iParent, SKGDocument* iDocument,
             m_Quick->rootContext()->setContextProperty(k, mapping[k]);
         }
         m_Quick->rootContext()->setContextProperty(QStringLiteral("periodWidget"), m_period);
+        m_Quick->rootContext()->setContextProperty(QStringLiteral("filterWidget"), m_filter);
         m_Quick->rootContext()->setContextProperty(QStringLiteral("panel"), SKGMainPanel::getMainPanel());
 
         setMainWidget(m_Quick);
@@ -115,6 +128,9 @@ SKGHtmlBoardWidget::SKGHtmlBoardWidget(QWidget* iParent, SKGDocument* iDocument,
             this->dataModified();
         });
     }
+    if (m_filter != nullptr) {
+        connect(m_filter, &KLineEdit::textChanged, this, &SKGHtmlBoardWidget::onTextFilterChanged);
+    }
     connect(SKGMainPanel::getMainPanel(), &SKGMainPanel::currentPageChanged, this, &SKGHtmlBoardWidget::pageChanged, Qt::QueuedConnection);
 }
 
@@ -122,6 +138,7 @@ SKGHtmlBoardWidget::~SKGHtmlBoardWidget()
 {
     SKGTRACEINFUNC(10)
     m_period = nullptr;
+    m_filter = nullptr;
     if (m_Report != nullptr) {
         delete m_Report;
         m_Report = nullptr;
@@ -139,7 +156,9 @@ QString SKGHtmlBoardWidget::getState()
     if (m_period != nullptr) {
         root.setAttribute(QStringLiteral("period"), m_period->text());
     }
-
+    if (m_filter != nullptr) {
+        root.setAttribute(QStringLiteral("filter"), m_filter->text());
+    }
     return doc.toString();
 }
 
@@ -164,7 +183,10 @@ void SKGHtmlBoardWidget::setState(const QString& iState)
             m_period->setText(oldMode == QStringLiteral("N") ? i18nc("The current month", "Current month") : i18nc("The month before the current month", "Last month"));
         }
     }
-
+    if (m_filter != nullptr) {
+        QString filter = root.attribute(QStringLiteral("filter"));
+        m_filter->setText(filter);
+    }
     dataModified(QLatin1String(""), 0);
 }
 
@@ -182,6 +204,37 @@ void SKGHtmlBoardWidget::pageChanged()
     }
 }
 
+void SKGHtmlBoardWidget::onTextFilterChanged(const QString& iFilter)
+{
+    auto tooltip = i18nc("Tooltip", "<html><head/><body><p>Searching is case-insensitive. So table, Table, and TABLE are all the same.<br/>"
+                         "If you just put a word or series of words in the search box, the application will filter the table to keep all lines having these words (logical operator AND). <br/>"
+                         "If you want to add (logical operator OR) some lines, you must prefix your word by '+'.<br/>"
+                         "If you want to remove (logical operator NOT) some lines, you must prefix your word by '-'.<br/>"
+                         "If you want to search only on some columns, you must prefix your word by the beginning of column name like: col1:word.<br/>"
+                         "If you want to search only on one column, you must prefix your word by the column name and a dot like: col1.:word.<br/>"
+                         "If you want to use the character ':' in value, you must specify the column name like this: col1:value:rest.<br/>"
+                         "If you want to search for a phrase or something that contains spaces, you must put it in quotes, like: 'yes, this is a phrase'.</p>"
+                         "<p>You can also use operators '&lt;', '&gt;', '&lt;=', '&gt;=', '=' and '#' (for regular expression).</p>"
+                         "<p><span style=\"font-weight:600; text-decoration: underline;\">Examples:</span><br/>"
+                         "+val1 +val2 =&gt; Keep lines containing val1 OR val2<br/>"
+                         "+val1 -val2 =&gt; Keep lines containing val1 but NOT val2<br/>"
+                         "'abc def' =&gt; Keep lines containing the sentence 'abc def' <br/>"
+                         "'-att:abc def' =&gt; Remove lines having a column name starting by abc and containing 'abc def' <br/>"
+                         "abc:def =&gt; Keep lines having a column name starting by abc and containing def<br/>"
+                         ":abc:def =&gt; Keep lines containing 'abc:def'<br/>"
+                         "Date&gt;2015-03-01 =&gt; Keep lines where at least one attribute starting by Date is greater than 2015-03-01<br/>"
+                         "Date.&gt;2015-03-01 =&gt; Keep lines where at the Date attribute is greater than 2015-03-01<br/>"
+                         "Amount&lt;10 =&gt;Keep lines where at least one attribute starting by Amount is less than 10<br/>"
+                         "Amount=10 =&gt;Keep lines where at least one attribute starting by Amount is equal to 10<br/>"
+                         "Amount&lt;=10 =&gt;Keep lines where at least one attribute starting by Amount is less or equal to 10<br/>"
+                         "abc#^d.*f$ =&gt; Keep lines having a column name starting by abc and matching the regular expression ^d.*f$</p>"
+                         "<span style=\"font-weight:600; text-decoration: underline;\">Your filter is understood like this:</span><br/>"
+                         "%1</body></html>", SKGServices::searchCriteriasToWhereClause(SKGServices::stringToSearchCriterias(iFilter), m_attributes, getDocument(), true));
+    m_filter->setToolTip(tooltip);
+
+    SKGHtmlBoardWidget::dataModified();
+}
+
 void SKGHtmlBoardWidget::dataModified(const QString& iTableName, int iIdTransaction)
 {
     SKGTRACEINFUNC(10)
@@ -196,6 +249,14 @@ void SKGHtmlBoardWidget::dataModified(const QString& iTableName, int iIdTransact
 
     if (m_Report != nullptr) {
         m_Report->setPeriod((m_period != nullptr ? m_period->period() : SKGServices::dateToPeriod(QDate::currentDate(), QStringLiteral("M"))));
+
+        if (m_filter) {
+            auto filterSQL = SKGServices::searchCriteriasToWhereClause(SKGServices::stringToSearchCriterias(m_filter->text()),
+                             m_attributes,
+                             getDocument(),
+                             false);
+            m_Report->setSqlFilter(filterSQL);
+        }
     }
 
     if (m_TablesRefreshing.isEmpty() || m_TablesRefreshing.contains(iTableName) || iTableName.isEmpty()) {
