@@ -28,6 +28,7 @@
 
 class QLabel;
 class QQuickWidget;
+class KLineEdit;
 class SKGReport;
 
 /**
@@ -45,8 +46,15 @@ public:
      * @param iTemplate the html template (.html) or the qml file (.qml)
      * @param iTablesRefreshing the list of table refreshing the report when the table is updated. (empty means all)
      * @param iOptions to enable options in menu
+     * @param iEnableFilter to enable the filter
      */
-    explicit SKGHtmlBoardWidget(QWidget* iParent, SKGDocument* iDocument, const QString& iTitle, const QString& iTemplate, QStringList  iTablesRefreshing = QStringList(), SKGSimplePeriodEdit::Modes iOptions = SKGSimplePeriodEdit::NONE);
+    explicit SKGHtmlBoardWidget(QWidget* iParent,
+                                SKGDocument* iDocument,
+                                const QString& iTitle,
+                                const QString& iTemplate,
+                                QStringList  iTablesRefreshing = QStringList(),
+                                SKGSimplePeriodEdit::Modes iOptions = SKGSimplePeriodEdit::NONE,
+                                const QStringList& iAttributesForFilter = QStringList());
 
     /**
      * Default Destructor
@@ -76,6 +84,7 @@ public:
 
 protected Q_SLOTS:
     void pageChanged();
+    void onTextFilterChanged(const QString& iFilter);
     virtual void dataModified(const QString& iTableName = QString(), int iIdTransaction = 0);
 
 protected:
@@ -91,6 +100,8 @@ private:
     bool m_refreshNeeded;
 
     SKGSimplePeriodEdit* m_period;
+    KLineEdit* m_filter;
+    QStringList m_attributes;
 };
 
 #endif  // SKGHTMLBOARDWIDGET_H
