@@ -467,29 +467,29 @@ QString SKGPeriodEdit::getWhereClause(bool iForecast, QString* oWhereClausForPre
 
         ui.kDateBegin->setDate(a);
         ui.kDateEnd->setDate(b);
-        wc = sqlAttribute % " = (SELECT period(date('now'), " % strfFormat % "))";
+        wc = sqlAttribute % " = (SELECT period(date('now', 'localtime'), " % strfFormat % "))";
         if (ui.kFuture->isChecked()) {
-            wc +=  QStringLiteral(" OR d_date > (SELECT date('now'))");
+            wc +=  QStringLiteral(" OR d_date > (SELECT date('now', 'localtime'))");
         }
         if (oWhereClausForPreviousData != nullptr) {
-            *oWhereClausForPreviousData = sqlAttribute % " < (SELECT period(date('now'), " % strfFormat % "))";
+            *oWhereClausForPreviousData = sqlAttribute % " < (SELECT period(date('now', 'localtime'), " % strfFormat % "))";
         }
         if (oWhereClausForForecastData != nullptr) {
-            *oWhereClausForForecastData = QStringLiteral("d_date > (SELECT date('now'))");
+            *oWhereClausForForecastData = QStringLiteral("d_date > (SELECT date('now', 'localtime'))");
         }
         break;
     case PREVIOUS:
         ui.kDateBegin->setDate(a);
         ui.kDateEnd->setDate(b);
-        wc = sqlAttribute % ">=(SELECT period(date('now','start of month', '-" % SKGServices::intToString(val) % ' ' % sqlInterval % "')," % strfFormat % "))";
+        wc = sqlAttribute % ">=(SELECT period(date('now', 'localtime','start of month', '-" % SKGServices::intToString(val) % ' ' % sqlInterval % "')," % strfFormat % "))";
         if (iForecast) {
-            wc += " AND period(d_date, " % strfFormat % ")<=(SELECT period(date('now','start of month', '-" % SKGServices::intToString(one) % ' ' % sqlInterval % "')," % strfFormat % "))";    // For forecast based on scheduled operations
+            wc += " AND period(d_date, " % strfFormat % ")<=(SELECT period(date('now', 'localtime','start of month', '-" % SKGServices::intToString(one) % ' ' % sqlInterval % "')," % strfFormat % "))";    // For forecast based on scheduled operations
 
             if (oWhereClausForPreviousData != nullptr) {
-                *oWhereClausForPreviousData = sqlAttribute % " < (SELECT period(date('now','start of month', '-" % SKGServices::intToString(val) % ' ' % sqlInterval % "')," % strfFormat % "))";
+                *oWhereClausForPreviousData = sqlAttribute % " < (SELECT period(date('now', 'localtime','start of month', '-" % SKGServices::intToString(val) % ' ' % sqlInterval % "')," % strfFormat % "))";
             }
             if (oWhereClausForForecastData != nullptr) {
-                *oWhereClausForForecastData = sqlAttribute % " > (SELECT period(date('now','start of month', '-" % SKGServices::intToString(one) % ' ' % sqlInterval % "')," % strfFormat % "))";
+                *oWhereClausForForecastData = sqlAttribute % " > (SELECT period(date('now', 'localtime','start of month', '-" % SKGServices::intToString(one) % ' ' % sqlInterval % "')," % strfFormat % "))";
             }
         }
         break;
@@ -501,19 +501,19 @@ QString SKGPeriodEdit::getWhereClause(bool iForecast, QString* oWhereClausForPre
         ui.kDateBegin->setDate(a);
         ui.kDateEnd->setDate(b);
 
-        wc = "d_date > (SELECT date('now','-" % SKGServices::intToString(val) % ' ' % sqlInterval % "'))";
+        wc = "d_date > (SELECT date('now', 'localtime','-" % SKGServices::intToString(val) % ' ' % sqlInterval % "'))";
         if (iForecast) {
-            wc += QStringLiteral(" AND d_date<=(SELECT date('now'))");    // For forecast based on scheduled operations
+            wc += QStringLiteral(" AND d_date<=(SELECT date('now', 'localtime'))");    // For forecast based on scheduled operations
         }
 
         if (ui.kFuture->isChecked()) {
-            wc += QStringLiteral(" OR d_date > (SELECT date('now'))");
+            wc += QStringLiteral(" OR d_date > (SELECT date('now', 'localtime'))");
         }
         if (oWhereClausForPreviousData != nullptr) {
-            *oWhereClausForPreviousData = "d_date <= (SELECT date('now','-" % SKGServices::intToString(val) % ' ' % sqlInterval % "'))";
+            *oWhereClausForPreviousData = "d_date <= (SELECT date('now', 'localtime','-" % SKGServices::intToString(val) % ' ' % sqlInterval % "'))";
         }
         if (oWhereClausForForecastData != nullptr) {
-            *oWhereClausForForecastData = QStringLiteral("d_date > (SELECT date('now'))");
+            *oWhereClausForForecastData = QStringLiteral("d_date > (SELECT date('now', 'localtime'))");
         }
         break;
     case CUSTOM:
@@ -526,7 +526,7 @@ QString SKGPeriodEdit::getWhereClause(bool iForecast, QString* oWhereClausForPre
             *oWhereClausForPreviousData = "d_date<'" % SKGServices::dateToSqlString(ui.kDateBegin->date()) % '\'';
         }
         if (oWhereClausForForecastData != nullptr) {
-            *oWhereClausForForecastData = QStringLiteral("d_date > (SELECT date('now'))");
+            *oWhereClausForForecastData = QStringLiteral("d_date > (SELECT date('now', 'localtime'))");
         }
         break;
     case TIMELINE:
@@ -554,7 +554,7 @@ QString SKGPeriodEdit::getWhereClause(bool iForecast, QString* oWhereClausForPre
             *oWhereClausForPreviousData = QStringLiteral("1=0");
         }
         if (oWhereClausForForecastData != nullptr) {
-            *oWhereClausForForecastData = QStringLiteral("d_date > (SELECT date('now'))");
+            *oWhereClausForForecastData = QStringLiteral("d_date > (SELECT date('now', 'localtime'))");
         }
         break;
     }
