@@ -27,9 +27,13 @@
 #include <qwidget.h>
 #ifdef SKG_WEBENGINE
 #include <qwebengineview.h>
-#else
+#endif
+#ifdef SKG_WEBKIT
 #include <qwebview.h>
 #endif
+#if !defined(SKG_WEBENGINE) && !defined(SKG_WEBKIT)
+#include <qlabel.h>
+#endif
 #include <qmath.h>
 
 #include <cmath>
@@ -261,10 +265,11 @@ void SKGTabPage::setZoomPosition(int iValue)
     } else {
 #ifdef SKG_WEBENGINE
         auto webView = qobject_cast<QWebEngineView*>(widget);
-#else
+#endif
+#ifdef SKG_WEBKIT
         auto webView = qobject_cast<QWebView*>(widget);
 #endif
-
+#if defined(SKG_WEBENGINE) || defined(SKG_WEBKIT)
         if (webView != nullptr) {
             webView->setZoomFactor(qPow(10, static_cast<qreal>(iValue) / 30.0));
         } else {
@@ -278,6 +283,7 @@ void SKGTabPage::setZoomPosition(int iValue)
                 c->setPointSize(pointSize);
             }
         }
+#endif
     }
 }
 
@@ -291,14 +297,17 @@ int SKGTabPage::zoomPosition()
     } else {
 #ifdef SKG_WEBENGINE
         auto webView = qobject_cast<QWebEngineView*>(widget);
-#else
+#endif
+#ifdef SKG_WEBKIT
         auto webView = qobject_cast<QWebView*>(widget);
 #endif
+#if defined(SKG_WEBENGINE) || defined(SKG_WEBKIT)
         if (webView != nullptr) {
             output = qRound(30.0 * log10(webView->zoomFactor()));
         } else if (widget != nullptr) {
             output = widget->font().pointSize() - m_fontOriginalPointSize;
         }
+#endif
     }
     return output;
 }
