@@ -859,7 +859,12 @@ void SKGTreeView::selectObjects(const QStringList& iUniqueIDs, bool iFocusOnFirs
                 for (int i = 0; i < nbRows; ++i) {
                     QModelIndex index = items.at(i);
                     SKGObjectBase obj = m_model->getObject(index);
-                    if (m_expandedNodes.contains(obj.getUniqueID())) {
+                    QString id = obj.getUniqueID();
+                    if (obj.getTable().isEmpty()) {
+                        // This is a group
+                        id = obj.getAttribute(QStringLiteral("t_title"));
+                    }
+                    if (m_expandedNodes.contains(id)) {
                         QModelIndex idxs = (m_proxyModel != nullptr ? m_proxyModel->mapFromSource(index) : index);
                         setExpanded(idxs, true);
                     }
@@ -936,6 +941,10 @@ void SKGTreeView::onExpand(const QModelIndex& index)
 
         SKGObjectBase obj = m_model->getObject(idxs);
         QString id = obj.getUniqueID();
+        if (obj.getTable().isEmpty()) {
+            // This is a group
+            id = obj.getAttribute(QStringLiteral("t_title"));
+        }
         m_expandedNodes.push_back(id);
     }
 
@@ -963,6 +972,10 @@ void SKGTreeView::onCollapse(const QModelIndex& index)
         SKGObjectBase obj = m_model->getObject(idxs);
 
         QString id = obj.getUniqueID();
+        if (obj.getTable().isEmpty()) {
+            // This is a group
+            id = obj.getAttribute(QStringLiteral("t_title"));
+        }
         m_expandedNodes.removeOne(id);
     }
 
@@ -991,47 +1004,29 @@ void SKGTreeView::copy()
 
         std::sort(indexes.begin(), indexes.end());
 
-        // You need a pair of indexes to find the row changes
-        QModelIndex previous = indexes.first();
-        indexes.removeFirst();
-
-        bool header_done = false;
         QStringList colums_title;
         colums_title.reserve(indexes.count());
         SKGStringListList columns_values;
-        int index = 0;
         for (const auto& current : qAsConst(indexes)) {
-            if (columns_values.count() < index + 1) {
-                columns_values.append(QStringList());
-                columns_values.append(QStringList());
+            auto header_title = model()->headerData(current.column(), Qt::Horizontal).toString();
+            if (header_title.isEmpty()) {
+                header_title = SKGServices::splitCSVLine(model()->headerData(current.column(), Qt::Horizontal, Qt::UserRole).toString(), QLatin1Char('|')).at(0);
             }
-            columns_values[index].append(model()->data(previous).toString());
-            columns_values[index + 1].append(model()->data(previous, Qt::UserRole).toString());
 
-            if (!header_done) {
-                auto header_title = model()->headerData(previous.column(), Qt::Horizontal).toString();
-                if (header_title.isEmpty()) {
-                    header_title = SKGServices::splitCSVLine(model()->headerData(previous.column(), Qt::Horizontal, Qt::UserRole).toString(), QLatin1Char('|')).at(0);
-                }
+            auto pos = colums_title.indexOf(header_title);
+            if (pos == -1) {
                 colums_title.append(header_title);
                 colums_title.append(header_title + QLatin1String("_raw"));
-            }
-            if (current.row() != previous.row()) {
-                index = 0;
-                header_done = true;
-            } else {
-                index = index + 2;
-            }
-            previous = current;
-        }
 
-        // Add last element
-        if (columns_values.count() < index + 1) {
-            columns_values.append(QStringList());
-            columns_values.append(QStringList());
+                columns_values.append(QStringList());
+                columns_values.append(QStringList());
+
+                pos = colums_title.count() - 2;
+            }
+
+            columns_values[pos].append(model()->data(current).toString());
+            columns_values[pos + 1].append(model()->data(current, Qt::UserRole).toString());
         }
-        columns_values[index].append(model()->data(previous).toString());
-        columns_values[index + 1].append(model()->data(previous, Qt::UserRole).toString());
 
         // Remove useless raw columns (when all raw values = displayed values)
         int nbCols = columns_values.count();
