@@ -32,11 +32,13 @@
 #include <qtextdocumentwriter.h>
 #ifdef SKG_WEBENGINE
 #include <qwebenginepage.h>
-#else
+#endif
+#ifdef SKG_WEBKIT
 #include <qwebframe.h>
 #endif
 #include <qfileinfo.h>
 #include <qmath.h>
+#include <qpainter.h>
 
 #include <kstandardaction.h>
 #include <qdir.h>
@@ -97,7 +99,8 @@ void SKGWebView::emitLinkClicked(const QUrl& iURL)
 {
     Q_EMIT linkClicked(iURL);
 }
-#else
+#endif
+#ifdef SKG_WEBKIT
 SKGWebView::SKGWebView(QWidget* iParent, const char* name)
     : QWebView(iParent)
 {
@@ -136,6 +139,21 @@ void SKGWebView::openReply(QNetworkReply* reply)
 }
 #endif
 
+#if !defined(SKG_WEBENGINE) && !defined(SKG_WEBKIT)
+SKGWebView::SKGWebView(QWidget* iParent, const char* name) : QScrollArea(iParent)
+{
+    auto label = new QLabel(this);
+    setWidget(label);
+    setWidgetResizable(true);
+
+    setObjectName(name);
+    label->setTextFormat(Qt::RichText);
+    connect(label, &QLabel::linkActivated, this, [ = ](const QString & val) {
+        SKGMainPanel::getMainPanel()->openPage(val);
+    });
+}
+#endif
+
 SKGWebView::~SKGWebView()
     = default;
 
@@ -145,7 +163,9 @@ QString SKGWebView::getState()
     QDomDocument doc(QStringLiteral("SKGML"));
     QDomElement root = doc.createElement(QStringLiteral("parameters"));
     doc.appendChild(root);
+#if defined(SKG_WEBENGINE) || defined(SKG_WEBKIT)
     root.setAttribute(QStringLiteral("zoomFactor"), SKGServices::intToString(qMax(qRound(30.0 * log10(zoomFactor())), -10)));
+#endif
     return doc.toString();
 }
 
@@ -155,6 +175,7 @@ void SKGWebView::setState(const QString& iState)
     QDomDocument doc(QStringLiteral("SKGML"));
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
+#if defined(SKG_WEBENGINE) || defined(SKG_WEBKIT)
     QString zoomPosition = root.attribute(QStringLiteral("zoomFactor"));
     if (zoomPosition.isEmpty()) {
         zoomPosition = '0';
@@ -162,15 +183,18 @@ void SKGWebView::setState(const QString& iState)
     double z = qPow(10, (static_cast<qreal>(SKGServices::stringToInt(zoomPosition)) / 30.0));
     setZoomFactor(z);
     emit zoomChanged(z);
+#endif
 }
 
+#if defined(SKG_WEBENGINE) || defined(SKG_WEBKIT)
 void SKGWebView::contextMenuEvent(QContextMenuEvent* iEvent)
 {
     if (iEvent != nullptr) {
         auto menu = new QMenu(this);
 #ifdef SKG_WEBENGINE
         menu->addAction(pageAction(QWebEnginePage::Copy));
-#else
+#endif
+#ifdef SKG_WEBKIT
         menu->addAction(pageAction(QWebPage::Copy));
 #endif
 
@@ -187,7 +211,7 @@ void SKGWebView::contextMenuEvent(QContextMenuEvent* iEvent)
         iEvent->accept();
     }
 }
-
+#endif
 bool SKGWebView::eventFilter(QObject* iObject, QEvent* iEvent)
 {
     SKGTRACEINFUNC(10)
@@ -214,27 +238,30 @@ bool SKGWebView::eventFilter(QObject* iObject, QEvent* iEvent)
 void SKGWebView::onZoomIn()
 {
     _SKGTRACEINFUNC(10)
+#if defined(SKG_WEBENGINE) || defined(SKG_WEBKIT)
     int z = qMin(static_cast<int>(qRound(30.0 * log10(zoomFactor()))) + 1, 10);
     setZoomFactor(qPow(10, static_cast<qreal>(z) / 30.0));
-
     emit zoomChanged(z);
+#endif
 }
 
 void SKGWebView::onZoomOut()
 {
     _SKGTRACEINFUNC(10)
+#if defined(SKG_WEBENGINE) || defined(SKG_WEBKIT)
     int z = qMax(static_cast<int>(qRound(30.0 * log10(zoomFactor()))) - 1, -10);
     setZoomFactor(qPow(10, static_cast<qreal>(z) / 30.0));
-
     emit zoomChanged(z);
+#endif
 }
 
 void SKGWebView::onZoomOriginal()
 {
     _SKGTRACEINFUNC(10)
+#if defined(SKG_WEBENGINE) || defined(SKG_WEBKIT)
     setZoomFactor(0);
-
     emit zoomChanged(0);
+#endif
 }
 
 void SKGWebView::exportInFile(const QString& iFileName)
@@ -250,7 +277,8 @@ void SKGWebView::exportInFile(const QString& iFileName)
 
             emit fileExporter(iFileName);
         });
-#else
+#endif
+#ifdef SKG_WEBKIT
         QTextDocument doc;
         QTextDocumentWriter docWriter(iFileName);
         doc.setHtml(page()->mainFrame()->toHtml());
@@ -262,7 +290,8 @@ void SKGWebView::exportInFile(const QString& iFileName)
 #ifdef SKG_WEBENGINE
         page()->printToPdf(iFileName);
         connect(page(), &QWebEnginePage::pdfPrintingFinished, this, &SKGWebView::fileExporter);
-#else
+#endif
+#ifdef SKG_WEBKIT
         QPrinter printer;
         printer.setOutputFileName(iFileName);
         print(&printer);
@@ -282,7 +311,8 @@ void SKGWebView::exportInFile(const QString& iFileName)
                 emit fileExporter(iFileName);
             }
         });
-#else
+#endif
+#ifdef SKG_WEBKIT
         QSaveFile file(iFileName);
         if (file.open(QIODevice::WriteOnly)) {
             QTextStream out(&file);
@@ -324,7 +354,8 @@ void SKGWebView::onPrintPreview()
     connect(dialog.data(), &QPrintPreviewDialog::paintRequested, page(), [&](QPrinter * printer) {
         page()->print(printer, [](bool) {});
     });
-#else
+#endif
+#ifdef SKG_WEBKIT
     connect(dialog.data(), &QPrintPreviewDialog::paintRequested, this, &SKGWebView::print);
 #endif
 
@@ -339,7 +370,8 @@ void SKGWebView::onPrint()
         QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 #ifdef SKG_WEBENGINE
         page()->print(&m_printer, [](bool) {});
-#else
+#endif
+#ifdef SKG_WEBKIT
         print(&m_printer);
 #endif
         QApplication::restoreOverrideCursor();
