@@ -92,6 +92,20 @@ QString SKGReport::getPeriod()
     return month;
 }
 
+void SKGReport::setSqlFilter(const QString& iFilter)
+{
+    if (iFilter != m_cache[QStringLiteral("filter")]) {
+        cleanCache(false);
+        m_cache[QStringLiteral("filter")] = iFilter;
+        emit changed();
+    }
+}
+
+QString SKGReport::getSqlFilter()
+{
+    return m_cache.value(QStringLiteral("filter")).toString();;
+}
+
 QString SKGReport::getPreviousPeriod()
 {
     QString previousmonth = m_cache.value(QStringLiteral("previousperiod")).toString();
@@ -223,10 +237,14 @@ SKGError SKGReport::getReportFromTemplate(SKGReport* iReport, const QString& iFi
 void SKGReport::cleanCache(bool iEmitSignal)
 {
     QString month = m_cache.value(QStringLiteral("period")).toString();
+    QString filter = m_cache.value(QStringLiteral("filter")).toString();
     m_cache.clear();
     if (!month.isEmpty()) {
         m_cache[QStringLiteral("period")] = month;
     }
+    if (!filter.isEmpty()) {
+        m_cache[QStringLiteral("filter")] = filter;
+    }
     if (iEmitSignal) {
         emit changed();
     }
