@@ -107,6 +107,18 @@ public:
      */
     Q_INVOKABLE virtual QString getPeriod();
 
+    /**
+     * Set the SQL filter
+     * @param iFilter the filter
+     */
+    Q_INVOKABLE virtual void setSqlFilter(const QString& iFilter);
+
+    /**
+     * Get the SQL filter
+     * @return the SQL filter
+     */
+    Q_INVOKABLE virtual QString getSqlFilter();
+
     /**
      * Get the previous period
      * @return the previous period
