@@ -989,7 +989,7 @@ QString SKGServices::getPeriodWhereClause(const QString& iPeriod, const QString&
             output = "STRFTIME('%Y-%m'," + SKGServices::stringToSqlString(iDateAttribute) + ")" + iComparator + "'" + SKGServices::stringToSqlString(iPeriod) + '\'';
         }
     }
-    if (iComparator == "<" || iComparator == "<=") {
+    if (iComparator == QStringLiteral("<") || iComparator == QStringLiteral("<=")) {
         output = "(" + output + " OR " + iDateAttribute + "='0000-00-00')";
     }
     return output;
