@@ -481,7 +481,7 @@ int main(int argc, char** argv)
         {
             // Create an account without number
             SKGBEGINTRANSACTION(document1, QStringLiteral("CREATE_ACCOUNT"), err)
-            SKGTESTERROR(QStringLiteral("DOC.addOrModifyAccount"), document1.addOrModifyAccount(QStringLiteral("COURANT"), QLatin1String("5823485"), QStringLiteral("BANK")), true)
+            SKGTESTERROR(QStringLiteral("DOC.addOrModifyAccount"), document1.addOrModifyAccount(QStringLiteral("COURANT"), QStringLiteral("5823485"), QStringLiteral("BANK")), true)
             SKGObjectBase account;
             SKGTESTERROR(QStringLiteral("DOC.getObject"), document1.getObject(QStringLiteral("v_account"), QStringLiteral("t_name='COURANT'"), account), true)
             SKGTESTERROR(QStringLiteral("ACCOUNT.setProperty"), account.setProperty(QStringLiteral("alias"), QStringLiteral("XXXX485")), true)
@@ -493,7 +493,7 @@ int main(int argc, char** argv)
             SKGTESTERROR(QStringLiteral("imp1.importFile"), imp1.importFile(), true)
             document1.dump(DUMPACCOUNT | DUMPPARAMETERS);
             int nb2 = 0;
-            SKGTESTERROR(QStringLiteral("imp1.getNbObjects"), document1.getNbObjects(QStringLiteral("account"), QStringLiteral(""), nb2), true)
+            SKGTESTERROR(QStringLiteral("imp1.getNbObjects"), document1.getNbObjects(QStringLiteral("account"), QString(), nb2), true)
             SKGTEST(QStringLiteral("ACCOUNT:nb"), SKGServices::intToString(nb2), QStringLiteral("1"))
         }
     }
