@@ -45,7 +45,7 @@ int main(int argc, char** argv)
             SKGBEGINTRANSACTION(document1, QStringLiteral("IMPORT_PDF"), err)
             QString dir = SKGTest::getTestPath(QStringLiteral("IN")) % "/skgtestimportpdf/";
             auto listFiles = QDir(dir).entryList(QStringList() << QStringLiteral("*.pdf"), QDir::Files, QDir::Name);
-            for (const auto& file : listFiles) {
+            for (const auto& file : qAsConst(listFiles)) {
                 SKGImportExportManager imp1(&document1, QUrl::fromLocalFile(dir % file));
                 SKGTESTERROR(QStringLiteral("imp1.importFile"), imp1.importFile(), true)
             }
