@@ -41,7 +41,7 @@ int main(int argc, char** argv)
     {
         QStringList sources = SKGUnitObject::downloadSources();
         SKGTESTBOOL("UNIT:downloadSources", (sources.count() >= 4), true)
-        for (const QString& source : sources) {
+        for (const QString& source : qAsConst(sources)) {
             SKGUnitObject::getCommentFromSource(source);
         }
 
