@@ -256,7 +256,7 @@ void test_errors(int& nberror, int& nbcheck, bool showonlyfailures)
         SKGTEST(QStringLiteral("ERR:getHistoricalSize"), err.getHistoricalSize(), 1)
         SKGTEST(QStringLiteral("ERR:RC 10"), err.getReturnCode(), 11)
         SKGTEST(QStringLiteral("ERR:MSG Message 11"), err.getMessage(), QStringLiteral("Message 11"))
-        err.setProperty("ABC");
+        err.setProperty(QStringLiteral("ABC"));
         SKGTEST(QStringLiteral("ERR:Property ABC"), err.getProperty(), QStringLiteral("ABC"))
     }
 }
